import numpy as np
import matplotlib.pyplot as plt
import matplotlib.gridspec as gridspec
import matplotlib.ticker as ticker
from collections import Counter
import scipy.stats
from scipy.stats import gaussian_kde

# Oppgi sti til mappen hvor matrisen ligger lagret
sti = 'C:\\Programmering\\'
innSti = sti + 'Python\\BruMatrise.npy'

# Kolonne 0 = Filnavn
# Kolonne 1 = Bruas ID i NVDB
# Kolonne 2 = Målepunktets avstand til brua [m]
# Kolonne 3 = Målepunktets friksjonsverdi
# Kolonne 4 = Vegens vinterdriftsklasse ved målepunktet
# Kolonne 5 = Lufttemperatur [Celsius]
# Kolonne 6 = Vegoverflatetemperatur [Celsius]
# Kolonne 7 = Luftfuktighet [%] OBS, ofte utilgjengelig
# Kolonne 8 = Brutype
# Kolonne 9 = Brumateriale
# Kolonne 10 = Bruas totale lengde [m]
# Kolonne 11 = Bruas byggeår. OBS, ofte utilgjengelig
# Kolonne 12 = Vegens horisontalradius [m]
# Kolonne 13 = Utstyr brukt under målingen
# Kolonne 14 = Vegens referanse (navn)
# Kolonne 15 = Fylke
# Kolonne 16 = Året målingen ble utført
# Kolonne 17 = Måneden målingen ble utført
# Kolonne 18 = Dagen målingen ble utført
# Kolonne 19 = Klokkeslett målingen ble utført

matrise = np.load(innSti)  # Laster inn matrisen

# Splitter matrisen med all data opp i mindre matriser hvor hver fil har sin matrise
unikeFilnavnIndekser = np.unique(matrise[:, 0], True)[1]
listeFilerMatriser = []
for i in range(len(unikeFilnavnIndekser)):
    if i < len(unikeFilnavnIndekser) - 1:
        a = unikeFilnavnIndekser[i]
        b = unikeFilnavnIndekser[i + 1]
        listeFilerMatriser.append(matrise[a:b, :])
    else:
        a = unikeFilnavnIndekser[i]
        b = len(matrise)
        listeFilerMatriser.append(matrise[a:b, :])

# Splitter fil-matrisene opp slik at hver ny matrise inneholder alle målepunktene forbundet til ei bestemt bru
listeBruerMatriser = []
for filerMatriser in listeFilerMatriser:
    bruIDerIndekser = np.sort(np.unique(filerMatriser[:, 1], True)[1])
    if len(bruIDerIndekser) > 0:
        for i in range(len(bruIDerIndekser)):
            if i < len(bruIDerIndekser) - 1:
                a = bruIDerIndekser[i]
                b = bruIDerIndekser[i + 1]
                listeBruerMatriser.append(filerMatriser[a:b, :])
            else:
                a = bruIDerIndekser[i]
                b = len(filerMatriser)
                listeBruerMatriser.append(filerMatriser[a:b, :])

# Sorterer bru-matrisene slik at avstanden til brua øker og noterer de fem settene med flest målepunkter rundt én bru
listeBruerMatriserSortert = []
lengst1 = []
lengst2 = []
lengst3 = []
lengst4 = []
lengst5 = []
lengst6 = []
for bruerMatriser in listeBruerMatriser:
    listeBruerMatriserSortert.append(bruerMatriser[np.argsort(bruerMatriser[:, 2])])

    # Noterer bruene med flest punkter:
    midlertidigListe = []
    for linje in bruerMatriser:
        if linje[1] != 'None':
            midlertidigListe.append(linje)
    if len(midlertidigListe) > len(lengst1):
        lengst6 = lengst5
        lengst5 = lengst4
        lengst4 = lengst3
        lengst3 = lengst2
        lengst2 = lengst1
        lengst1 = midlertidigListe
    elif len(midlertidigListe) > len(lengst2):
        lengst6 = lengst5
        lengst5 = lengst4
        lengst4 = lengst3
        lengst3 = lengst2
        lengst2 = midlertidigListe
    elif len(midlertidigListe) > len(lengst3):
        lengst6 = lengst5
        lengst5 = lengst4
        lengst4 = lengst3
        lengst3 = midlertidigListe
    elif len(midlertidigListe) > len(lengst4):
        lengst6 = lengst5
        lengst5 = lengst4
        lengst4 = midlertidigListe
    elif len(midlertidigListe) > len(lengst5):
        lengst6 = lengst5
        lengst5 = midlertidigListe
    elif len(midlertidigListe) > len(lengst6):
        lengst6 = midlertidigListe

# Fordeler de seks utvalgte bruene med tanke på kronologisk målt friksjonsverdi
teller = -1
xAkseLengst1 = []
yAkseLengst1 = []
xAkseBruLengst1 = []
yAkseBruLengst1 = []
for linje in lengst1:
    teller = teller + 1
    xAkseLengst1.append(teller)
    yAkseLengst1.append(float(linje[3]))
    if linje[2] == '0.0':
        xAkseBruLengst1.append(teller)
        yAkseBruLengst1.append(float(linje[3]))
teller = -1
xAkseLengst2 = []
yAkseLengst2 = []
xAkseBruLengst2 = []
yAkseBruLengst2 = []
for linje in lengst2:
    teller = teller + 1
    xAkseLengst2.append(teller)
    yAkseLengst2.append(float(linje[3]))
    if linje[2] == '0.0':
        xAkseBruLengst2.append(teller)
        yAkseBruLengst2.append(float(linje[3]))
teller = -1
xAkseLengst3 = []
yAkseLengst3 = []
xAkseBruLengst3 = []
yAkseBruLengst3 = []
for linje in lengst3:
    teller = teller + 1
    xAkseLengst3.append(teller)
    yAkseLengst3.append(float(linje[3]))
    if linje[2] == '0.0':
        xAkseBruLengst3.append(teller)
        yAkseBruLengst3.append(float(linje[3]))
teller = -1
xAkseLengst4 = []
yAkseLengst4 = []
xAkseBruLengst4 = []
yAkseBruLengst4 = []
for linje in lengst4:
    teller = teller + 1
    xAkseLengst4.append(teller)
    yAkseLengst4.append(float(linje[3]))
    if linje[2] == '0.0':
        xAkseBruLengst4.append(teller)
        yAkseBruLengst4.append(float(linje[3]))
teller = -1
xAkseLengst5 = []
yAkseLengst5 = []
xAkseBruLengst5 = []
yAkseBruLengst5 = []
for linje in lengst5:
    teller = teller + 1
    xAkseLengst5.append(teller)
    yAkseLengst5.append(float(linje[3]))
    if linje[2] == '0.0':
        xAkseBruLengst5.append(teller)
        yAkseBruLengst5.append(float(linje[3]))
teller = -1
xAkseLengst6 = []
yAkseLengst6 = []
xAkseBruLengst6 = []
yAkseBruLengst6 = []
for linje in lengst6:
    teller = teller + 1
    xAkseLengst6.append(teller)
    yAkseLengst6.append(float(linje[3]))
    if linje[2] == '0.0':
        xAkseBruLengst6.append(teller)
        yAkseBruLengst6.append(float(linje[3]))


# Definerer en funksjon som kan si om innholdet er NULL eller ikke
def isfloat(value):
    try:
        float(value)
        return True
    except ValueError:
        return False


klokkeslett8_20 = []
klokkeslett20_8 = []
friksjonLavestPaaBruTeller0 = 0
friksjonLavestPaaBruTeller1 = 0
friksjonLavestPaaBruTeller2 = 0
friksjonLavestPaaBruTeller3 = 0
minBruFriksjonListe0 = []
minBruFriksjonListe1 = []
minBruFriksjonListe2 = []
minBruFriksjonListe3 = []
sortertMatriseTeller = 0
bruSett = []
fylkesnummerListe = []
friksjonsverdierPaaBruListe = []
friksjonsverdierPaaBruListeSortert = []
luftTemperaturPaaBruListe = []
vegTemperaturPaaBruListe = []
avstanderTilBruListe = []
relativFriksjonsverdierMedianListe = []
relativFriksjonsverdierMinListe = []
luftfuktighetLavTemperaturPaaBruListe = []
luftfuktighetLavTemperaturPaaBruFriksjonsverdierListe = []
luftfuktighetLavTemperaturUtenforBruListe = []
luftfuktighetLavTemperaturUtenforBruFriksjonsverdierListe = []
luftfuktighetHoyTemperaturPaaBruListe = []
luftfuktighetHoyTemperaturPaaBruFriksjonsverdierListe = []
luftfuktighetHoyTemperaturUtenforBruListe = []
luftfuktighetHoyTemperaturUtenforBruFriksjonsverdierListe = []
antallBruer = 0
antallBrupunkter = 0
avstanderTilBruListeDriftsklasse = []
relativFriksjonsverdierMedianListeDriftsklasse = []
relativFriksjonsverdierMinListeDriftsklasse = []
friksjonsverdierListeDriftsklasseAlle = []
luftTemperaturListe = []
vegTemperaturListe = []
relativVegTemperaturListe = []
driftsklasseListe = []
bruMaterialeListe = []
# Finner friksjonsverdien som er nærmest brua. Dersom det er målt flere verdier på brua beregnes medianverdien
for bruerMatriserSortert in listeBruerMatriserSortert:
    sortertMatriseTeller = sortertMatriseTeller + 1
    usortertMatriseTeller = 0
    for linje in bruerMatriserSortert:

        # Undersøker hvordan friksjon på bruer påvirkes av lufttemperatur og vegoverflatetemperatur
        if linje[2] == '0.0':
            friksjonsverdierPaaBruListe.append(float(linje[3]))
            luftTemperaturPaaBruListe.append(float(linje[5]))
            vegTemperaturPaaBruListe.append(float(linje[6]))
            friksjonsverdierPaaBruListeSortert.append(linje[3])

        # Undersøker hvordan friksjon på bruer og utenfor bruer påvirkes av luftfuktiget
        if isfloat(linje[7]) is True:
            if float(linje[6]) <= 0 and float(linje[7]) > 0:  # Målinger med vegoverflatetemperatur under frysepunktet
                if linje[2] == '0.0':  # Målinger på bru
                    luftfuktighetLavTemperaturPaaBruListe.append(float(linje[7]))
                    luftfuktighetLavTemperaturPaaBruFriksjonsverdierListe.append(float(linje[3]))
                else:  # Målinger utenfor bru
                    luftfuktighetLavTemperaturUtenforBruListe.append(float(linje[7]))
                    luftfuktighetLavTemperaturUtenforBruFriksjonsverdierListe.append(float(linje[3]))
            elif float(linje[6]) > 0 and float(
                    linje[7]) > 0:  # Målinger med vegoverflatetemperatur over frysepunktet, opp til 1Celsius
                if linje[2] == '0.0':  # Målinger på bru
                    luftfuktighetHoyTemperaturPaaBruListe.append(float(linje[7]))
                    luftfuktighetHoyTemperaturPaaBruFriksjonsverdierListe.append(float(linje[3]))
                else:  # Målinger utenfor bru
                    luftfuktighetHoyTemperaturUtenforBruListe.append(float(linje[7]))
                    luftfuktighetHoyTemperaturUtenforBruFriksjonsverdierListe.append(float(linje[3]))

    friksjonsverdierPaaBruListeSortert.sort()  # Sorterer listen med generelle friksjonsverdier på bruer i stigende rekkefølge

    nullAvstandIndekser = np.where(bruerMatriserSortert[:, 2] == '0.0')[
        0]  # Finner plasseringen i matrisen hvor avstanden til brua er null
    if nullAvstandIndekser.size > 0:
        for linje in bruerMatriserSortert:  # Noterer klokkeslett for målingene
            klokkeslett = linje[19]
            klokkeslettTime = int(klokkeslett[:2])
            if 8 <= klokkeslettTime < 20:
                klokkeslett8_20.append(klokkeslettTime)
            elif klokkeslettTime < 8 or klokkeslettTime >= 20:
                klokkeslett20_8.append(klokkeslettTime)

        antallBruer = antallBruer + 1
        antallBrupunkter = antallBrupunkter + len(bruerMatriserSortert)
        nullAvstandfriksjonsverdier = np.asarray(bruerMatriserSortert[0:nullAvstandIndekser.size, 3], dtype=np.float64,
                                                 order='C')
        medianBruFriksjon = np.percentile(nullAvstandfriksjonsverdier,
                                          50)  # Finner median friksjonsverdi til målepunktene på selve brua
        minBruFriksjon = np.amin(nullAvstandfriksjonsverdier)
        maxBruFriksjon = np.amax(nullAvstandfriksjonsverdier)
        driftsklasseBru = bruerMatriserSortert[0][4]

        nullAvstandVegtemperaturer = np.asarray(bruerMatriserSortert[0:nullAvstandIndekser.size, 6], dtype=np.float64,
                                                order='C')
        medianBruVegtemperatur = np.percentile(nullAvstandVegtemperaturer,
                                               50)  # Finner median vegtemperatur til målepunktene på selve brua

        fylkesnummer = np.asarray(bruerMatriserSortert[:, 15], dtype=np.float64, order='C')
        for fylke in fylkesnummer:
            fylkesnummerListe.append(fylke)

        # Noterer avstand til bru friksjon og temperatur for alle punkter
        avstanderTilBru = np.asarray(bruerMatriserSortert[:, 2], dtype=np.float64, order='C')
        for avstand in avstanderTilBru:
            avstanderTilBruListe.append(avstand)  # Legger til avstandsverdiene i en liste (brukes som x-koordinater)

        friksjonsverdier = np.asarray(bruerMatriserSortert[:, 3], dtype=np.float64, order='C')
        for friksjon in friksjonsverdier:  # Legger til friksjonsverdiene i en liste (brukes som y-koordinater)
            relativFriksjonsverdierMedianListe.append(friksjon - medianBruFriksjon)
            relativFriksjonsverdierMinListe.append(friksjon - minBruFriksjon)

        friksjonsverdierRundtBru = np.asarray(bruerMatriserSortert[nullAvstandIndekser.size:, 3], dtype=np.float64,
                                              order='C')
        if friksjonsverdierRundtBru.size > 0:
            minFriksjonRundtBru = np.amin(friksjonsverdierRundtBru)
            if minFriksjonRundtBru > minBruFriksjon:
                if minFriksjonRundtBru < minBruFriksjon + 0.05:
                    friksjonLavestPaaBruTeller0 = friksjonLavestPaaBruTeller0 + 1
                    minBruFriksjonListe0.append(minBruFriksjon)
                if minBruFriksjon + 0.05 <= minFriksjonRundtBru < minBruFriksjon + 0.1:
                    friksjonLavestPaaBruTeller1 = friksjonLavestPaaBruTeller1 + 1
                    minBruFriksjonListe1.append(minBruFriksjon)
                if minBruFriksjon + 0.10 <= minFriksjonRundtBru < minBruFriksjon + 0.15:
                    friksjonLavestPaaBruTeller2 = friksjonLavestPaaBruTeller2 + 1
                    minBruFriksjonListe2.append(minBruFriksjon)
                if minFriksjonRundtBru >= minBruFriksjon + 0.15:
                    friksjonLavestPaaBruTeller3 = friksjonLavestPaaBruTeller3 + 1
                    minBruFriksjonListe3.append(minBruFriksjon)
                    for bruerMatriser in listeBruerMatriser:
                        usortertMatriseTeller = usortertMatriseTeller + 1
                        if usortertMatriseTeller == sortertMatriseTeller:
                            bruSett.append(bruerMatriser)

        luftTemperaturer = np.asarray(bruerMatriserSortert[:, 5], dtype=np.float64, order='C')
        for luftTemperatur in luftTemperaturer:
            luftTemperaturListe.append(luftTemperatur)  # Legger til vegtemperatur i en liste (brukes som x-koordinater)

        vegTemperaturer = np.asarray(bruerMatriserSortert[:, 6], dtype=np.float64, order='C')
        for vegTemperatur in vegTemperaturer:
            relativVegTemperaturListe.append((
                    vegTemperatur - medianBruVegtemperatur))  # Legger til vegtemperatur relativ vegtemperaturen målt på brua i ei liste
            vegTemperaturListe.append(vegTemperatur)  # Legger til vegtemperatur i en liste

        # Samler friksjon, avstand og brumateriale sortert etter driftsklasse
        driftsklasser = np.asarray(bruerMatriserSortert[:, 4], order='C')
        teller = -1
        for driftsklasse in driftsklasser:
            teller = teller + 1
            if driftsklasse == driftsklasseBru and driftsklasse != 'None':
                avstanderTilBruListeDriftsklasse.append(float(bruerMatriserSortert[teller][2]))
                relativFriksjonsverdierMedianListeDriftsklasse.append(
                    float(bruerMatriserSortert[teller][3]) - medianBruFriksjon)
                relativFriksjonsverdierMinListeDriftsklasse.append(
                    float(bruerMatriserSortert[teller][3]) - minBruFriksjon)
                friksjonsverdierListeDriftsklasseAlle.append(float(bruerMatriserSortert[teller][3]))
                driftsklasseListe.append(bruerMatriserSortert[teller][4])
                bruMaterialeListe.append(bruerMatriserSortert[teller][9])
minBruFriksjonListe0.sort()
minBruFriksjonListe1.sort()
minBruFriksjonListe2.sort()
minBruFriksjonListe3.sort()
bruSettFriksjon = []
bruSettFriksjonBru = []
bruSettVegoverflate = []
brusettTall = []
brusettTallBru = []
for bruMatrise in bruSett:
    midlertidigListeFriksjon = []
    midlertidigListeFriksjonBru = []
    midlertidigListeTall = []
    midlertidigListeTallBru = []
    midlertidigListeVegoverflate = []
    teller = -1
    for linje in bruMatrise:
        teller = teller + 1
        midlertidigListeFriksjon.append(float(linje[3]))
        midlertidigListeVegoverflate.append(float(linje[6]))
        midlertidigListeTall.append(teller)
        if linje[2] == '0.0':
            midlertidigListeFriksjonBru.append(float(linje[3]))
            midlertidigListeTallBru.append(teller)
    bruSettFriksjon.append(midlertidigListeFriksjon)
    bruSettFriksjonBru.append(midlertidigListeFriksjonBru)
    bruSettVegoverflate.append(midlertidigListeVegoverflate)
    brusettTall.append(midlertidigListeTall)
    brusettTallBru.append(midlertidigListeTallBru)

# Fordeler avstand og friksjon basert på driftsklasse
avstandListeDkA = []
avstandListeDkB1 = []
avstandListeDkB2 = []
avstandListeDkB3 = []
avstandListeDkC = []
avstandListeDkD = []
avstandListeDkE = []
relativFriksjonsverdierMedianListeDkA = []
friksjonsverdierListeDkA = []
relativFriksjonsverdierMedianListeDkB1 = []
friksjonsverdierListeDkB1 = []
relativFriksjonsverdierMedianListeDkB2 = []
friksjonsverdierListeDkB2 = []
relativFriksjonsverdierMedianListeDkB3 = []
friksjonsverdierListeDkB3 = []
relativFriksjonsverdierMedianListeDkC = []
friksjonsverdierListeDkC = []
relativFriksjonsverdierMedianListeDkD = []
friksjonsverdierListeDkD = []
relativFriksjonsverdierMedianListeDkE = []
friksjonsverdierListeDkE = []
bruMaterialeListeDkA = []
bruMaterialeListeDkB1 = []
bruMaterialeListeDkB2 = []
bruMaterialeListeDkB3 = []
bruMaterialeListeDkC = []
bruMaterialeListeDkD = []
bruMaterialeListeDkE = []
driftsklasseTeller = -1
for driftsklasse in driftsklasseListe:
    driftsklasseTeller = driftsklasseTeller + 1
    if driftsklasse == 'DkA':
        relativFriksjonsverdierMedianListeDkA.append(relativFriksjonsverdierMedianListeDriftsklasse[driftsklasseTeller])
        avstandListeDkA.append(avstanderTilBruListeDriftsklasse[driftsklasseTeller])
        friksjonsverdierListeDkA.append(friksjonsverdierListeDriftsklasseAlle[driftsklasseTeller])
        bruMaterialeListeDkA.append(bruMaterialeListe[driftsklasseTeller])
    elif driftsklasse == 'DkB, høy':
        relativFriksjonsverdierMedianListeDkB1.append(
            relativFriksjonsverdierMedianListeDriftsklasse[driftsklasseTeller])
        avstandListeDkB1.append(avstanderTilBruListeDriftsklasse[driftsklasseTeller])
        friksjonsverdierListeDkB1.append(friksjonsverdierListeDriftsklasseAlle[driftsklasseTeller])
        bruMaterialeListeDkB1.append(bruMaterialeListe[driftsklasseTeller])
    elif driftsklasse == 'DkB, middels':
        relativFriksjonsverdierMedianListeDkB2.append(
            relativFriksjonsverdierMedianListeDriftsklasse[driftsklasseTeller])
        avstandListeDkB2.append(avstanderTilBruListeDriftsklasse[driftsklasseTeller])
        friksjonsverdierListeDkB2.append(friksjonsverdierListeDriftsklasseAlle[driftsklasseTeller])
        bruMaterialeListeDkB2.append(bruMaterialeListe[driftsklasseTeller])
    elif driftsklasse == 'DkB, lav':
        relativFriksjonsverdierMedianListeDkB3.append(
            relativFriksjonsverdierMedianListeDriftsklasse[driftsklasseTeller])
        avstandListeDkB3.append(avstanderTilBruListeDriftsklasse[driftsklasseTeller])
        friksjonsverdierListeDkB3.append(friksjonsverdierListeDriftsklasseAlle[driftsklasseTeller])
        bruMaterialeListeDkB3.append(bruMaterialeListe[driftsklasseTeller])
    elif driftsklasse == 'DkC':
        relativFriksjonsverdierMedianListeDkC.append(relativFriksjonsverdierMedianListeDriftsklasse[driftsklasseTeller])
        avstandListeDkC.append(avstanderTilBruListeDriftsklasse[driftsklasseTeller])
        friksjonsverdierListeDkC.append(friksjonsverdierListeDriftsklasseAlle[driftsklasseTeller])
        bruMaterialeListeDkC.append(bruMaterialeListe[driftsklasseTeller])
    elif driftsklasse == 'DkD':
        relativFriksjonsverdierMedianListeDkD.append(relativFriksjonsverdierMedianListeDriftsklasse[driftsklasseTeller])
        avstandListeDkD.append(avstanderTilBruListeDriftsklasse[driftsklasseTeller])
        friksjonsverdierListeDkD.append(friksjonsverdierListeDriftsklasseAlle[driftsklasseTeller])
        bruMaterialeListeDkD.append(bruMaterialeListe[driftsklasseTeller])
    elif driftsklasse == 'DkE':
        relativFriksjonsverdierMedianListeDkE.append(relativFriksjonsverdierMedianListeDriftsklasse[driftsklasseTeller])
        avstandListeDkE.append(avstanderTilBruListeDriftsklasse[driftsklasseTeller])
        friksjonsverdierListeDkE.append(friksjonsverdierListeDriftsklasseAlle[driftsklasseTeller])
        bruMaterialeListeDkE.append(bruMaterialeListe[driftsklasseTeller])
friksjonsverdierListeDriftsklasseAlleBru = []
friksjonsverdierListeDriftsklasseAlleUtenfor = []
bruMaterialeListeDriftsklasseAlleBru = []
friksjonsverdierListeDkABru = []
friksjonsverdierListeDkAUtenfor = []
friksjonsverdierListeDkABruUsortert = []
bruMaterialeListeDkABru = []
for i in range(len(avstandListeDkA)):
    if avstandListeDkA[i] == 0:
        friksjonsverdierListeDkABru.append(friksjonsverdierListeDkA[i])
        friksjonsverdierListeDkABruUsortert.append(friksjonsverdierListeDkA[i])
        friksjonsverdierListeDriftsklasseAlleBru.append(friksjonsverdierListeDkA[i])
        bruMaterialeListeDkABru.append(bruMaterialeListeDkA[i])
        bruMaterialeListeDriftsklasseAlleBru.append(bruMaterialeListeDkA[i])
    else:
        friksjonsverdierListeDkAUtenfor.append(friksjonsverdierListeDkA[i])
        friksjonsverdierListeDriftsklasseAlleUtenfor.append(friksjonsverdierListeDkA[i])
friksjonsverdierListeDkB1Bru = []
friksjonsverdierListeDkB1Utenfor = []
friksjonsverdierListeDkB1BruUsortert = []
bruMaterialeListeDkB1Bru = []
for i in range(len(avstandListeDkB1)):
    if avstandListeDkB1[i] == 0:
        friksjonsverdierListeDkB1Bru.append(friksjonsverdierListeDkB1[i])
        friksjonsverdierListeDkB1BruUsortert.append(friksjonsverdierListeDkB1[i])
        friksjonsverdierListeDriftsklasseAlleBru.append(friksjonsverdierListeDkB1[i])
        bruMaterialeListeDkB1Bru.append(bruMaterialeListeDkB1[i])
        bruMaterialeListeDriftsklasseAlleBru.append(bruMaterialeListeDkB1[i])
    else:
        friksjonsverdierListeDkB1Utenfor.append(friksjonsverdierListeDkB1[i])
        friksjonsverdierListeDriftsklasseAlleUtenfor.append(friksjonsverdierListeDkB1[i])
friksjonsverdierListeDkB2Bru = []
friksjonsverdierListeDkB2Utenfor = []
friksjonsverdierListeDkB2BruUsortert = []
bruMaterialeListeDkB2Bru = []
for i in range(len(avstandListeDkB2)):
    if avstandListeDkB2[i] == 0:
        friksjonsverdierListeDkB2Bru.append(friksjonsverdierListeDkB2[i])
        friksjonsverdierListeDkB2BruUsortert.append(friksjonsverdierListeDkB2[i])
        friksjonsverdierListeDriftsklasseAlleBru.append(friksjonsverdierListeDkB2[i])
        bruMaterialeListeDkB2Bru.append(bruMaterialeListeDkB2[i])
        bruMaterialeListeDriftsklasseAlleBru.append(bruMaterialeListeDkB2[i])
    else:
        friksjonsverdierListeDkB2Utenfor.append(friksjonsverdierListeDkB2[i])
        friksjonsverdierListeDriftsklasseAlleUtenfor.append(friksjonsverdierListeDkB2[i])
friksjonsverdierListeDkB3Bru = []
friksjonsverdierListeDkB3Utenfor = []
friksjonsverdierListeDkB3BruUsortert = []
bruMaterialeListeDkB3Bru = []
for i in range(len(avstandListeDkB3)):
    if avstandListeDkB3[i] == 0:
        friksjonsverdierListeDkB3Bru.append(friksjonsverdierListeDkB3[i])
        friksjonsverdierListeDkB3BruUsortert.append(friksjonsverdierListeDkB3[i])
        friksjonsverdierListeDriftsklasseAlleBru.append(friksjonsverdierListeDkB3[i])
        bruMaterialeListeDkB3Bru.append(bruMaterialeListeDkB3[i])
        bruMaterialeListeDriftsklasseAlleBru.append(bruMaterialeListeDkB3[i])
    else:
        friksjonsverdierListeDkB3Utenfor.append(friksjonsverdierListeDkB3[i])
        friksjonsverdierListeDriftsklasseAlleUtenfor.append(friksjonsverdierListeDkB3[i])
friksjonsverdierListeDkCBru = []
friksjonsverdierListeDkCUtenfor = []
friksjonsverdierListeDkCBruUsortert = []
bruMaterialeListeDkCBru = []
for i in range(len(avstandListeDkC)):
    if avstandListeDkC[i] == 0:
        friksjonsverdierListeDkCBru.append(friksjonsverdierListeDkC[i])
        friksjonsverdierListeDkCBruUsortert.append(friksjonsverdierListeDkC[i])
        friksjonsverdierListeDriftsklasseAlleBru.append(friksjonsverdierListeDkC[i])
        bruMaterialeListeDkCBru.append(bruMaterialeListeDkC[i])
        bruMaterialeListeDriftsklasseAlleBru.append(bruMaterialeListeDkC[i])
    else:
        friksjonsverdierListeDkCUtenfor.append(friksjonsverdierListeDkC[i])
        friksjonsverdierListeDriftsklasseAlleUtenfor.append(friksjonsverdierListeDkC[i])
friksjonsverdierListeDkDBru = []
friksjonsverdierListeDkDUtenfor = []
friksjonsverdierListeDkDBruUsortert = []
bruMaterialeListeDkDBru = []
for i in range(len(avstandListeDkD)):
    if avstandListeDkD[i] == 0:
        friksjonsverdierListeDkDBru.append(friksjonsverdierListeDkD[i])
        friksjonsverdierListeDkDBruUsortert.append(friksjonsverdierListeDkD[i])
        friksjonsverdierListeDriftsklasseAlleBru.append(friksjonsverdierListeDkD[i])
        bruMaterialeListeDkDBru.append(bruMaterialeListeDkD[i])
        bruMaterialeListeDriftsklasseAlleBru.append(bruMaterialeListeDkD[i])
    else:
        friksjonsverdierListeDkDUtenfor.append(friksjonsverdierListeDkD[i])
        friksjonsverdierListeDriftsklasseAlleUtenfor.append(friksjonsverdierListeDkD[i])
friksjonsverdierListeDkEBru = []
friksjonsverdierListeDkEUtenfor = []
friksjonsverdierListeDkEBruUsortert = []
bruMaterialeListeDkEBru = []
for i in range(len(avstandListeDkE)):
    if avstandListeDkE[i] == 0:
        friksjonsverdierListeDkEBru.append(friksjonsverdierListeDkE[i])
        friksjonsverdierListeDkEBruUsortert.append(friksjonsverdierListeDkE[i])
        friksjonsverdierListeDriftsklasseAlleBru.append(friksjonsverdierListeDkE[i])
        bruMaterialeListeDkEBru.append(bruMaterialeListeDkE[i])
        bruMaterialeListeDriftsklasseAlleBru.append(bruMaterialeListeDkE[i])
    else:
        friksjonsverdierListeDkEUtenfor.append(friksjonsverdierListeDkE[i])
        friksjonsverdierListeDriftsklasseAlleUtenfor.append(friksjonsverdierListeDkE[i])
friksjonsverdierListeDkABru.sort()
friksjonsverdierListeDkAUtenfor.sort()
friksjonsverdierListeDkA.sort()
friksjonsverdierListeDkB1Bru.sort()
friksjonsverdierListeDkB1Utenfor.sort()
friksjonsverdierListeDkB1.sort()
friksjonsverdierListeDkB2Bru.sort()
friksjonsverdierListeDkB2Utenfor.sort()
friksjonsverdierListeDkB2.sort()
friksjonsverdierListeDkB3Bru.sort()
friksjonsverdierListeDkB3Utenfor.sort()
friksjonsverdierListeDkB3.sort()
friksjonsverdierListeDkCBru.sort()
friksjonsverdierListeDkCUtenfor.sort()
friksjonsverdierListeDkC.sort()
friksjonsverdierListeDkDBru.sort()
friksjonsverdierListeDkDUtenfor.sort()
friksjonsverdierListeDkD.sort()
friksjonsverdierListeDkEBru.sort()
friksjonsverdierListeDkEUtenfor.sort()
friksjonsverdierListeDkE.sort()
friksjonsverdierListeDriftsklasseAlleBru.sort()
friksjonsverdierListeDriftsklasseAlleUtenfor.sort()
friksjonsverdierListeDriftsklasseAlle.sort()

# Legger til brumaterialet for alle friksjonsverdier
bruMaterialeListeDkA5persentil = []
for i in range(len(friksjonsverdierListeDkABruUsortert)):
    if friksjonsverdierListeDkABruUsortert[i] <= friksjonsverdierListeDkABru[round(len(friksjonsverdierListeDkABru) * 0.05)]:
        bruMaterialeListeDkA5persentil.append(bruMaterialeListeDkABru[i])
bruMaterialeListeDkB15persentil = []
for i in range(len(friksjonsverdierListeDkB1BruUsortert)):
    if friksjonsverdierListeDkB1BruUsortert[i] <= friksjonsverdierListeDkB1Bru[round(len(friksjonsverdierListeDkB1Bru) * 0.05)]:
        bruMaterialeListeDkB15persentil.append(bruMaterialeListeDkB1Bru[i])
bruMaterialeListeDkB25persentil = []
for i in range(len(friksjonsverdierListeDkB2BruUsortert)):
    if friksjonsverdierListeDkB2BruUsortert[i] <= friksjonsverdierListeDkB2Bru[round(len(friksjonsverdierListeDkB2Bru) * 0.05)]:
        bruMaterialeListeDkB25persentil.append(bruMaterialeListeDkB2Bru[i])
bruMaterialeListeDkB35persentil = []
for i in range(len(friksjonsverdierListeDkB3BruUsortert)):
    if friksjonsverdierListeDkB3BruUsortert[i] <= friksjonsverdierListeDkB3Bru[round(len(friksjonsverdierListeDkB3Bru) * 0.05)]:
        bruMaterialeListeDkB35persentil.append(bruMaterialeListeDkB3Bru[i])
bruMaterialeListeDkC5persentil = []
for i in range(len(friksjonsverdierListeDkCBruUsortert)):
    if friksjonsverdierListeDkCBruUsortert[i] <= friksjonsverdierListeDkCBru[round(len(friksjonsverdierListeDkCBru) * 0.05)]:
        bruMaterialeListeDkC5persentil.append(bruMaterialeListeDkCBru[i])
bruMaterialeListeDkD5persentil = []
for i in range(len(friksjonsverdierListeDkDBruUsortert)):
    if friksjonsverdierListeDkDBruUsortert[i] <= friksjonsverdierListeDkDBru[round(len(friksjonsverdierListeDkDBru) * 0.05)]:
        bruMaterialeListeDkD5persentil.append(bruMaterialeListeDkDBru[i])
bruMaterialeListeDkE5persentil = []
for i in range(len(friksjonsverdierListeDkEBruUsortert)):
    if friksjonsverdierListeDkEBruUsortert[i] <= friksjonsverdierListeDkEBru[round(len(friksjonsverdierListeDkEBru) * 0.05)]:
        bruMaterialeListeDkE5persentil.append(bruMaterialeListeDkEBru[i])

friksjonsverdierMatriseDkAlleBru = np.asarray(friksjonsverdierListeDriftsklasseAlleBru)
friksjonsverdierMatriseDkAlleUtenfor = np.asarray(friksjonsverdierListeDriftsklasseAlleUtenfor)
friksjonsverdierMatriseDkAlle = np.asarray(friksjonsverdierListeDriftsklasseAlle)
friksjonsverdierMatriseDkABru = np.asarray(friksjonsverdierListeDkABru)
friksjonsverdierMatriseDkAUtenfor = np.asarray(friksjonsverdierListeDkAUtenfor)
friksjonsverdierMatriseDkA = np.asarray(friksjonsverdierListeDkA)
friksjonsverdierMatriseDkB1Bru = np.asarray(friksjonsverdierListeDkB1Bru)
friksjonsverdierMatriseDkB1Utenfor = np.asarray(friksjonsverdierListeDkB1Utenfor)
friksjonsverdierMatriseDkB1 = np.asarray(friksjonsverdierListeDkB1)
friksjonsverdierMatriseDkB2Bru = np.asarray(friksjonsverdierListeDkB2Bru)
friksjonsverdierMatriseDkB2Utenfor = np.asarray(friksjonsverdierListeDkB2Utenfor)
friksjonsverdierMatriseDkB2 = np.asarray(friksjonsverdierListeDkB2)
friksjonsverdierMatriseDkB3Bru = np.asarray(friksjonsverdierListeDkB3Bru)
friksjonsverdierMatriseDkB3Utenfor = np.asarray(friksjonsverdierListeDkB3Utenfor)
friksjonsverdierMatriseDkB3 = np.asarray(friksjonsverdierListeDkB3)
friksjonsverdierMatriseDkCBru = np.asarray(friksjonsverdierListeDkCBru)
friksjonsverdierMatriseDkCUtenfor = np.asarray(friksjonsverdierListeDkCUtenfor)
friksjonsverdierMatriseDkC = np.asarray(friksjonsverdierListeDkC)
friksjonsverdierMatriseDkDBru = np.asarray(friksjonsverdierListeDkDBru)
friksjonsverdierMatriseDkDUtenfor = np.asarray(friksjonsverdierListeDkDUtenfor)
friksjonsverdierMatriseDkD = np.asarray(friksjonsverdierListeDkD)
friksjonsverdierMatriseDkEBru = np.asarray(friksjonsverdierListeDkEBru)
friksjonsverdierMatriseDkEUtenfor = np.asarray(friksjonsverdierListeDkEUtenfor)
friksjonsverdierMatriseDkE = np.asarray(friksjonsverdierListeDkE)

friksjonsverdierMatriseDkAlleBru_mean = np.mean(friksjonsverdierMatriseDkAlleBru)
friksjonsverdierMatriseDkAlleUtenfor_mean = np.mean(friksjonsverdierMatriseDkAlleUtenfor)
friksjonsverdierMatriseDkAlle_mean = np.mean(friksjonsverdierMatriseDkAlle)
friksjonsverdierMatriseDkABru_mean = np.mean(friksjonsverdierMatriseDkABru)
friksjonsverdierMatriseDkAUtenfor_mean = np.mean(friksjonsverdierMatriseDkAUtenfor)
friksjonsverdierMatriseDkA_mean = np.mean(friksjonsverdierMatriseDkA)
friksjonsverdierMatriseDkB1Bru_mean = np.mean(friksjonsverdierMatriseDkB1Bru)
friksjonsverdierMatriseDkB1Utenfor_mean = np.mean(friksjonsverdierMatriseDkB1Utenfor)
friksjonsverdierMatriseDkB1_mean = np.mean(friksjonsverdierMatriseDkB1)
friksjonsverdierMatriseDkB2Bru_mean = np.mean(friksjonsverdierMatriseDkB2Bru)
friksjonsverdierMatriseDkB2Utenfor_mean = np.mean(friksjonsverdierMatriseDkB2Utenfor)
friksjonsverdierMatriseDkB2_mean = np.mean(friksjonsverdierMatriseDkB2)
friksjonsverdierMatriseDkB3Bru_mean = np.mean(friksjonsverdierMatriseDkB3Bru)
friksjonsverdierMatriseDkB3Utenfor_mean = np.mean(friksjonsverdierMatriseDkB3Utenfor)
friksjonsverdierMatriseDkB3_mean = np.mean(friksjonsverdierMatriseDkB3)
friksjonsverdierMatriseDkCBru_mean = np.mean(friksjonsverdierMatriseDkCBru)
friksjonsverdierMatriseDkCUtenfor_mean = np.mean(friksjonsverdierMatriseDkCUtenfor)
friksjonsverdierMatriseDkC_mean = np.mean(friksjonsverdierMatriseDkC)
friksjonsverdierMatriseDkDBru_mean = np.mean(friksjonsverdierMatriseDkDBru)
friksjonsverdierMatriseDkDUtenfor_mean = np.mean(friksjonsverdierMatriseDkDUtenfor)
friksjonsverdierMatriseDkD_mean = np.mean(friksjonsverdierMatriseDkD)
friksjonsverdierMatriseDkEBru_mean = np.mean(friksjonsverdierMatriseDkEBru)
friksjonsverdierMatriseDkEUtenfor_mean = np.mean(friksjonsverdierMatriseDkEUtenfor)
friksjonsverdierMatriseDkE_mean = np.mean(friksjonsverdierMatriseDkE)

friksjonsverdierMatriseDkAlleBru_std = np.std(friksjonsverdierMatriseDkAlleBru)
friksjonsverdierMatriseDkAlleUtenfor_std = np.std(friksjonsverdierMatriseDkAlleUtenfor)
friksjonsverdierMatriseDkABru_std = np.std(friksjonsverdierMatriseDkABru)
friksjonsverdierMatriseDkAUtenfor_std = np.std(friksjonsverdierMatriseDkAUtenfor)
friksjonsverdierMatriseDkB1Bru_std = np.std(friksjonsverdierMatriseDkB1Bru)
friksjonsverdierMatriseDkB1Utenfor_std = np.std(friksjonsverdierMatriseDkB1Utenfor)
friksjonsverdierMatriseDkB2Bru_std = np.std(friksjonsverdierMatriseDkB2Bru)
friksjonsverdierMatriseDkB2Utenfor_std = np.std(friksjonsverdierMatriseDkB2Utenfor)
friksjonsverdierMatriseDkB3Bru_std = np.std(friksjonsverdierMatriseDkB3Bru)
friksjonsverdierMatriseDkB3Utenfor_std = np.std(friksjonsverdierMatriseDkB3Utenfor)
friksjonsverdierMatriseDkCBru_std = np.std(friksjonsverdierMatriseDkCBru)
friksjonsverdierMatriseDkCUtenfor_std = np.std(friksjonsverdierMatriseDkCUtenfor)
friksjonsverdierMatriseDkDBru_std = np.std(friksjonsverdierMatriseDkDBru)
friksjonsverdierMatriseDkDUtenfor_std = np.std(friksjonsverdierMatriseDkDUtenfor)
friksjonsverdierMatriseDkEBru_std = np.std(friksjonsverdierMatriseDkEBru)
friksjonsverdierMatriseDkEUtenfor_std = np.std(friksjonsverdierMatriseDkEUtenfor)

gjennomsnittBru = [friksjonsverdierMatriseDkAlleBru_mean, friksjonsverdierMatriseDkABru_mean,
                   friksjonsverdierMatriseDkB1Bru_mean, friksjonsverdierMatriseDkB2Bru_mean,
                   friksjonsverdierMatriseDkB3Bru_mean, friksjonsverdierMatriseDkCBru_mean,
                   friksjonsverdierMatriseDkDBru_mean, friksjonsverdierMatriseDkEBru_mean]
gjennomsnittUtenfor = [friksjonsverdierMatriseDkAlleUtenfor_mean, friksjonsverdierMatriseDkAUtenfor_mean,
                       friksjonsverdierMatriseDkB1Utenfor_mean, friksjonsverdierMatriseDkB2Utenfor_mean,
                       friksjonsverdierMatriseDkB3Utenfor_mean, friksjonsverdierMatriseDkCUtenfor_mean,
                       friksjonsverdierMatriseDkDUtenfor_mean, friksjonsverdierMatriseDkEUtenfor_mean]
standardavvikBru = [friksjonsverdierMatriseDkAlleBru_std, friksjonsverdierMatriseDkABru_std,
                    friksjonsverdierMatriseDkB1Bru_std, friksjonsverdierMatriseDkB2Bru_std,
                    friksjonsverdierMatriseDkB3Bru_std, friksjonsverdierMatriseDkCBru_std,
                    friksjonsverdierMatriseDkDBru_std, friksjonsverdierMatriseDkEBru_std]
standardavvikUtenfor = [friksjonsverdierMatriseDkAlleUtenfor_std, friksjonsverdierMatriseDkAUtenfor_std,
                        friksjonsverdierMatriseDkB1Utenfor_std, friksjonsverdierMatriseDkB2Utenfor_std,
                        friksjonsverdierMatriseDkB3Utenfor_std, friksjonsverdierMatriseDkCUtenfor_std,
                        friksjonsverdierMatriseDkDUtenfor_std, friksjonsverdierMatriseDkEUtenfor_std]

DkASignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkABru, friksjonsverdierMatriseDkAlleBru_mean, axis=0, nan_policy='propagate', alternative='greater')
DkB1Signifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkB1Bru, friksjonsverdierMatriseDkAlleBru_mean, axis=0, nan_policy='propagate', alternative='greater')
DkB2Signifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkB2Bru, friksjonsverdierMatriseDkAlleBru_mean, axis=0, nan_policy='propagate', alternative='greater')
DkB3Signifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkB3Bru, friksjonsverdierMatriseDkAlleBru_mean, axis=0, nan_policy='propagate', alternative='greater')
DkCSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkCBru, friksjonsverdierMatriseDkAlleBru_mean, axis=0, nan_policy='propagate', alternative='less')
DkDSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkDBru, friksjonsverdierMatriseDkAlleBru_mean, axis=0, nan_policy='propagate', alternative='less')
DkESignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkEBru, friksjonsverdierMatriseDkAlleBru_mean, axis=0, nan_policy='propagate', alternative='less')

DkAGjennomsnittSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkABru, friksjonsverdierMatriseDkA_mean, axis=0, nan_policy='propagate', alternative='greater')
DkB1GjennomsnittSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkB1Bru, friksjonsverdierMatriseDkB1_mean, axis=0, nan_policy='propagate', alternative='greater')
DkB2GjennomsnittSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkB2Bru, friksjonsverdierMatriseDkB2_mean, axis=0, nan_policy='propagate', alternative='greater')
DkB3GjennomsnittSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkB3Bru, friksjonsverdierMatriseDkB3_mean, axis=0, nan_policy='propagate', alternative='greater')
DkCGjennomsnittSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkCBru, friksjonsverdierMatriseDkC_mean, axis=0, nan_policy='propagate', alternative='less')
DkDGjennomsnittSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkDBru, friksjonsverdierMatriseDkD_mean, axis=0, nan_policy='propagate', alternative='less')
DkEGjennomsnittSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkEBru, friksjonsverdierMatriseDkE_mean, axis=0, nan_policy='propagate', alternative='less')
DkAlleGjennomsnittSignifikans = scipy.stats.ttest_1samp(friksjonsverdierMatriseDkAlleBru, friksjonsverdierMatriseDkAlle_mean, axis=0, nan_policy='propagate', alternative='less')

# Fordeler 5-persentilene i egne lister for på bru, utenfor bru, og alle
friksjonsverdierListeDriftsklasseBru = [friksjonsverdierListeDkABru, friksjonsverdierListeDkB1Bru,
                                        friksjonsverdierListeDkB2Bru, friksjonsverdierListeDkB3Bru,
                                        friksjonsverdierListeDkCBru, friksjonsverdierListeDkDBru,
                                        friksjonsverdierListeDkEBru, friksjonsverdierListeDriftsklasseAlleBru]
friksjonsverdierListeDkABru5persentil = []
friksjonsverdierListeDkB1Bru5persentil = []
friksjonsverdierListeDkB2Bru5persentil = []
friksjonsverdierListeDkB3Bru5persentil = []
friksjonsverdierListeDkCBru5persentil = []
friksjonsverdierListeDkDBru5persentil = []
friksjonsverdierListeDkEBru5persentil = []
friksjonsverdierListeDriftsklasseAlleBru5persentil = []
friksjonsverdierListeDriftsklasseBru5persentil = [friksjonsverdierListeDkABru5persentil, friksjonsverdierListeDkB1Bru5persentil,
                                                  friksjonsverdierListeDkB2Bru5persentil, friksjonsverdierListeDkB3Bru5persentil,
                                                  friksjonsverdierListeDkCBru5persentil, friksjonsverdierListeDkDBru5persentil,
                                                  friksjonsverdierListeDkEBru5persentil, friksjonsverdierListeDriftsklasseAlleBru5persentil]
teller = -1
for friksjonsverdiliste in friksjonsverdierListeDriftsklasseBru:
    midlertidigListe = []
    teller = teller + 1
    for i in range(round(len(friksjonsverdiliste)*0.05)):
        midlertidigListe.append(friksjonsverdiliste[i])
    friksjonsverdierListeDriftsklasseBru5persentil[teller] = midlertidigListe

friksjonsverdierListeDriftsklasseUtenfor = [friksjonsverdierListeDkAUtenfor, friksjonsverdierListeDkB1Utenfor,
                                            friksjonsverdierListeDkB2Utenfor, friksjonsverdierListeDkB3Utenfor,
                                            friksjonsverdierListeDkCUtenfor, friksjonsverdierListeDkDUtenfor,
                                            friksjonsverdierListeDkEUtenfor, friksjonsverdierListeDriftsklasseAlleUtenfor]
friksjonsverdierListeDkAUtenfor5persentil = []
friksjonsverdierListeDkB1Utenfor5persentil = []
friksjonsverdierListeDkB2Utenfor5persentil = []
friksjonsverdierListeDkB3Utenfor5persentil = []
friksjonsverdierListeDkCUtenfor5persentil = []
friksjonsverdierListeDkDUtenfor5persentil = []
friksjonsverdierListeDkEUtenfor5persentil = []
friksjonsverdierListeDriftsklasseAlleUtenfor5persentil = []
friksjonsverdierListeDriftsklasseUtenfor5persentil = [friksjonsverdierListeDkAUtenfor5persentil, friksjonsverdierListeDkB1Utenfor5persentil,
                                                      friksjonsverdierListeDkB2Utenfor5persentil, friksjonsverdierListeDkB3Utenfor5persentil,
                                                      friksjonsverdierListeDkCUtenfor5persentil, friksjonsverdierListeDkDUtenfor5persentil,
                                                      friksjonsverdierListeDkEUtenfor5persentil, friksjonsverdierListeDriftsklasseAlleUtenfor5persentil]
teller = -1
for friksjonsverdiliste in friksjonsverdierListeDriftsklasseUtenfor:
    midlertidigListe = []
    teller = teller + 1
    for i in range(round(len(friksjonsverdiliste)*0.05)):
        midlertidigListe.append(friksjonsverdiliste[i])
    friksjonsverdierListeDriftsklasseUtenfor5persentil[teller] = midlertidigListe

friksjonsverdierListeDriftsklasse = [friksjonsverdierListeDkA, friksjonsverdierListeDkB1,
                                     friksjonsverdierListeDkB2, friksjonsverdierListeDkB3,
                                     friksjonsverdierListeDkC, friksjonsverdierListeDkD,
                                     friksjonsverdierListeDkE, friksjonsverdierListeDriftsklasseAlle]
friksjonsverdierListeDkA5persentil = []
friksjonsverdierListeDkB15persentil = []
friksjonsverdierListeDkB25persentil = []
friksjonsverdierListeDkB35persentil = []
friksjonsverdierListeDkC5persentil = []
friksjonsverdierListeDkD5persentil = []
friksjonsverdierListeDkE5persentil = []
friksjonsverdierListeDriftsklasseAlle5persentil = []
friksjonsverdierListeDriftsklasse5persentil = [friksjonsverdierListeDkA5persentil, friksjonsverdierListeDkB15persentil,
                                               friksjonsverdierListeDkB25persentil, friksjonsverdierListeDkB35persentil,
                                               friksjonsverdierListeDkC5persentil, friksjonsverdierListeDkD5persentil,
                                               friksjonsverdierListeDkE5persentil, friksjonsverdierListeDriftsklasseAlle5persentil]
teller = -1
for friksjonsverdiliste in friksjonsverdierListeDriftsklasse:
    midlertidigListe = []
    teller = teller + 1
    for i in range(round(len(friksjonsverdiliste)*0.05)):
        midlertidigListe.append(friksjonsverdiliste[i])
    friksjonsverdierListeDriftsklasse5persentil[teller] = midlertidigListe

friksjonsverdierListeDkABru15persentil = []
friksjonsverdierListeDkB1Bru15persentil = []
friksjonsverdierListeDkB2Bru15persentil = []
friksjonsverdierListeDkB3Bru15persentil = []
friksjonsverdierListeDkCBru15persentil = []
friksjonsverdierListeDkDBru15persentil = []
friksjonsverdierListeDkEBru15persentil = []
friksjonsverdierListeDriftsklasseAlleBru15persentil = []
friksjonsverdierListeDriftsklasseBru15persentil = [friksjonsverdierListeDkABru15persentil, friksjonsverdierListeDkB1Bru15persentil,
                                                   friksjonsverdierListeDkB2Bru15persentil, friksjonsverdierListeDkB3Bru15persentil,
                                                   friksjonsverdierListeDkCBru15persentil, friksjonsverdierListeDkDBru15persentil,
                                                   friksjonsverdierListeDkEBru15persentil, friksjonsverdierListeDriftsklasseAlleBru15persentil]
teller = -1
for friksjonsverdiliste in friksjonsverdierListeDriftsklasseBru:
    midlertidigListe = []
    teller = teller + 1
    for i in range(round(len(friksjonsverdiliste)*0.15)):
        midlertidigListe.append(friksjonsverdiliste[i])
    friksjonsverdierListeDriftsklasseBru15persentil[teller] = midlertidigListe

friksjonsverdierListeDriftsklasseUtenfor = [friksjonsverdierListeDkAUtenfor, friksjonsverdierListeDkB1Utenfor,
                                            friksjonsverdierListeDkB2Utenfor, friksjonsverdierListeDkB3Utenfor,
                                            friksjonsverdierListeDkCUtenfor, friksjonsverdierListeDkDUtenfor,
                                            friksjonsverdierListeDkEUtenfor, friksjonsverdierListeDriftsklasseAlleUtenfor]
friksjonsverdierListeDkAUtenfor15persentil = []
friksjonsverdierListeDkB1Utenfor15persentil = []
friksjonsverdierListeDkB2Utenfor15persentil = []
friksjonsverdierListeDkB3Utenfor15persentil = []
friksjonsverdierListeDkCUtenfor15persentil = []
friksjonsverdierListeDkDUtenfor15persentil = []
friksjonsverdierListeDkEUtenfor15persentil = []
friksjonsverdierListeDriftsklasseAlleUtenfor15persentil = []
friksjonsverdierListeDriftsklasseUtenfor15persentil = [friksjonsverdierListeDkAUtenfor15persentil, friksjonsverdierListeDkB1Utenfor15persentil,
                                                       friksjonsverdierListeDkB2Utenfor15persentil, friksjonsverdierListeDkB3Utenfor15persentil,
                                                       friksjonsverdierListeDkCUtenfor15persentil, friksjonsverdierListeDkDUtenfor15persentil,
                                                       friksjonsverdierListeDkEUtenfor15persentil, friksjonsverdierListeDriftsklasseAlleUtenfor15persentil]
teller = -1
for friksjonsverdiliste in friksjonsverdierListeDriftsklasseUtenfor:
    midlertidigListe = []
    teller = teller + 1
    for i in range(round(len(friksjonsverdiliste)*0.15)):
        midlertidigListe.append(friksjonsverdiliste[i])
    friksjonsverdierListeDriftsklasseUtenfor15persentil[teller] = midlertidigListe

friksjonsverdierListeDriftsklasse = [friksjonsverdierListeDkA, friksjonsverdierListeDkB1,
                                     friksjonsverdierListeDkB2, friksjonsverdierListeDkB3,
                                     friksjonsverdierListeDkC, friksjonsverdierListeDkD,
                                     friksjonsverdierListeDkE, friksjonsverdierListeDriftsklasseAlle]
friksjonsverdierListeDkA15persentil = []
friksjonsverdierListeDkB115persentil = []
friksjonsverdierListeDkB215persentil = []
friksjonsverdierListeDkB315persentil = []
friksjonsverdierListeDkC15persentil = []
friksjonsverdierListeDkD15persentil = []
friksjonsverdierListeDkE15persentil = []
friksjonsverdierListeDriftsklasseAlle15persentil = []
friksjonsverdierListeDriftsklasse15persentil = [friksjonsverdierListeDkA15persentil, friksjonsverdierListeDkB115persentil,
                                                friksjonsverdierListeDkB215persentil, friksjonsverdierListeDkB315persentil,
                                                friksjonsverdierListeDkC15persentil, friksjonsverdierListeDkD15persentil,
                                                friksjonsverdierListeDkE15persentil, friksjonsverdierListeDriftsklasseAlle15persentil]
teller = -1
for friksjonsverdiliste in friksjonsverdierListeDriftsklasse:
    midlertidigListe = []
    teller = teller + 1
    for i in range(round(len(friksjonsverdiliste)*0.15)):
        midlertidigListe.append(friksjonsverdiliste[i])
    friksjonsverdierListeDriftsklasse15persentil[teller] = midlertidigListe

# Gjør 5-persentil-listene til matriser og finner gjennomsnittsverdien for "alle"
friksjonsverdierMatriseDkABru5persentil = []
friksjonsverdierMatriseDkB1Bru5persentil = []
friksjonsverdierMatriseDkB2Bru5persentil = []
friksjonsverdierMatriseDkB3Bru5persentil = []
friksjonsverdierMatriseDkCBru5persentil = []
friksjonsverdierMatriseDkDBru5persentil = []
friksjonsverdierMatriseDkEBru5persentil = []
friksjonsverdierMatriseDriftsklasseAlleBru5persentil = []
friksjonsverdierMatriseDkAUtenfor5persentil = []
friksjonsverdierMatriseDkB1Utenfor5persentil = []
friksjonsverdierMatriseDkB2Utenfor5persentil = []
friksjonsverdierMatriseDkB3Utenfor5persentil = []
friksjonsverdierMatriseDkCUtenfor5persentil = []
friksjonsverdierMatriseDkDUtenfor5persentil = []
friksjonsverdierMatriseDkEUtenfor5persentil = []
friksjonsverdierMatriseDriftsklasseAlleUtenfor5persentil = []
friksjonsverdierMatriseDkA5persentil = []
friksjonsverdierMatriseDkB15persentil = []
friksjonsverdierMatriseDkB25persentil = []
friksjonsverdierMatriseDkB35persentil = []
friksjonsverdierMatriseDkC5persentil = []
friksjonsverdierMatriseDkD5persentil = []
friksjonsverdierMatriseDkE5persentil = []
friksjonsverdierMatriseDriftsklasseAlle5persentil = []
friksjonsverdierMatriseDkA5persentil_mean = 0
friksjonsverdierMatriseDkB15persentil_mean = 0
friksjonsverdierMatriseDkB25persentil_mean = 0
friksjonsverdierMatriseDkB35persentil_mean = 0
friksjonsverdierMatriseDkC5persentil_mean = 0
friksjonsverdierMatriseDkD5persentil_mean = 0
friksjonsverdierMatriseDkE5persentil_mean = 0
friksjonsverdierMatriseDriftsklasseAlle5persentil_mean = 0

friksjonsverdierMatriseDriftsklasseBru5persentil = [friksjonsverdierMatriseDkABru5persentil, friksjonsverdierMatriseDkB1Bru5persentil,
                                                    friksjonsverdierMatriseDkB2Bru5persentil, friksjonsverdierMatriseDkB3Bru5persentil,
                                                    friksjonsverdierMatriseDkCBru5persentil, friksjonsverdierMatriseDkDBru5persentil,
                                                    friksjonsverdierMatriseDkEBru5persentil, friksjonsverdierMatriseDriftsklasseAlleBru5persentil]
friksjonsverdierMatriseDriftsklasseUtenfor5persentil = [friksjonsverdierMatriseDkAUtenfor5persentil, friksjonsverdierMatriseDkB1Utenfor5persentil,
                                                        friksjonsverdierMatriseDkB2Utenfor5persentil, friksjonsverdierMatriseDkB3Utenfor5persentil,
                                                        friksjonsverdierMatriseDkCUtenfor5persentil, friksjonsverdierMatriseDkDUtenfor5persentil,
                                                        friksjonsverdierMatriseDkEUtenfor5persentil, friksjonsverdierMatriseDriftsklasseAlleUtenfor5persentil]
friksjonsverdierMatriseDriftsklasse5persentil = [friksjonsverdierMatriseDkA5persentil, friksjonsverdierMatriseDkB15persentil,
                                                 friksjonsverdierMatriseDkB25persentil, friksjonsverdierMatriseDkB35persentil,
                                                 friksjonsverdierMatriseDkC5persentil, friksjonsverdierMatriseDkD5persentil,
                                                 friksjonsverdierMatriseDkE5persentil, friksjonsverdierMatriseDriftsklasseAlle5persentil]
friksjonsverdierMatriseDriftsklasse5persentil_mean = [friksjonsverdierMatriseDkA5persentil_mean, friksjonsverdierMatriseDkB15persentil_mean,
                                                      friksjonsverdierMatriseDkB25persentil_mean, friksjonsverdierMatriseDkB35persentil_mean,
                                                      friksjonsverdierMatriseDkC5persentil_mean, friksjonsverdierMatriseDkD5persentil_mean,
                                                      friksjonsverdierMatriseDkE5persentil_mean, friksjonsverdierMatriseDriftsklasseAlle5persentil_mean]

for i in range(len(friksjonsverdierMatriseDriftsklasseBru5persentil)):
    friksjonsverdierMatriseDriftsklasseBru5persentil[i] = np.asarray(friksjonsverdierListeDriftsklasseBru5persentil[i])
    friksjonsverdierMatriseDriftsklasseUtenfor5persentil[i] = np.asarray(friksjonsverdierListeDriftsklasseUtenfor5persentil[i])
    friksjonsverdierMatriseDriftsklasse5persentil[i] = np.asarray(friksjonsverdierListeDriftsklasse5persentil[i])
    friksjonsverdierMatriseDriftsklasse5persentil_mean[i] = np.mean(friksjonsverdierMatriseDriftsklasse5persentil[i])

# Gjør 5-persentil-listene til matriser og finner gjennomsnittsverdien for "alle"
friksjonsverdierMatriseDkABru15persentil = []
friksjonsverdierMatriseDkB1Bru15persentil = []
friksjonsverdierMatriseDkB2Bru15persentil = []
friksjonsverdierMatriseDkB3Bru15persentil = []
friksjonsverdierMatriseDkCBru15persentil = []
friksjonsverdierMatriseDkDBru15persentil = []
friksjonsverdierMatriseDkEBru15persentil = []
friksjonsverdierMatriseDriftsklasseAlleBru15persentil = []
friksjonsverdierMatriseDkAUtenfor15persentil = []
friksjonsverdierMatriseDkB1Utenfor15persentil = []
friksjonsverdierMatriseDkB2Utenfor15persentil = []
friksjonsverdierMatriseDkB3Utenfor15persentil = []
friksjonsverdierMatriseDkCUtenfor15persentil = []
friksjonsverdierMatriseDkDUtenfor15persentil = []
friksjonsverdierMatriseDkEUtenfor15persentil = []
friksjonsverdierMatriseDriftsklasseAlleUtenfor15persentil = []
friksjonsverdierMatriseDkA15persentil = []
friksjonsverdierMatriseDkB115persentil = []
friksjonsverdierMatriseDkB215persentil = []
friksjonsverdierMatriseDkB315persentil = []
friksjonsverdierMatriseDkC15persentil = []
friksjonsverdierMatriseDkD15persentil = []
friksjonsverdierMatriseDkE15persentil = []
friksjonsverdierMatriseDriftsklasseAlle15persentil = []
friksjonsverdierMatriseDkA15persentil_mean = 0
friksjonsverdierMatriseDkB115persentil_mean = 0
friksjonsverdierMatriseDkB215persentil_mean = 0
friksjonsverdierMatriseDkB315persentil_mean = 0
friksjonsverdierMatriseDkC15persentil_mean = 0
friksjonsverdierMatriseDkD15persentil_mean = 0
friksjonsverdierMatriseDkE15persentil_mean = 0
friksjonsverdierMatriseDriftsklasseAlle15persentil_mean = 0

friksjonsverdierMatriseDriftsklasseBru15persentil = [friksjonsverdierMatriseDkABru15persentil, friksjonsverdierMatriseDkB1Bru15persentil,
                                                     friksjonsverdierMatriseDkB2Bru15persentil, friksjonsverdierMatriseDkB3Bru15persentil,
                                                     friksjonsverdierMatriseDkCBru15persentil, friksjonsverdierMatriseDkDBru15persentil,
                                                     friksjonsverdierMatriseDkEBru15persentil, friksjonsverdierMatriseDriftsklasseAlleBru15persentil]
friksjonsverdierMatriseDriftsklasseUtenfor15persentil = [friksjonsverdierMatriseDkAUtenfor15persentil, friksjonsverdierMatriseDkB1Utenfor15persentil,
                                                         friksjonsverdierMatriseDkB2Utenfor15persentil, friksjonsverdierMatriseDkB3Utenfor15persentil,
                                                         friksjonsverdierMatriseDkCUtenfor15persentil, friksjonsverdierMatriseDkDUtenfor15persentil,
                                                         friksjonsverdierMatriseDkEUtenfor15persentil, friksjonsverdierMatriseDriftsklasseAlleUtenfor15persentil]
friksjonsverdierMatriseDriftsklasse15persentil = [friksjonsverdierMatriseDkA15persentil, friksjonsverdierMatriseDkB115persentil,
                                                  friksjonsverdierMatriseDkB215persentil, friksjonsverdierMatriseDkB315persentil,
                                                  friksjonsverdierMatriseDkC15persentil, friksjonsverdierMatriseDkD15persentil,
                                                  friksjonsverdierMatriseDkE15persentil, friksjonsverdierMatriseDriftsklasseAlle15persentil]
friksjonsverdierMatriseDriftsklasse15persentil_mean = [friksjonsverdierMatriseDkA15persentil_mean, friksjonsverdierMatriseDkB115persentil_mean,
                                                       friksjonsverdierMatriseDkB215persentil_mean, friksjonsverdierMatriseDkB315persentil_mean,
                                                       friksjonsverdierMatriseDkC15persentil_mean, friksjonsverdierMatriseDkD15persentil_mean,
                                                       friksjonsverdierMatriseDkE15persentil_mean, friksjonsverdierMatriseDriftsklasseAlle15persentil_mean]

for i in range(len(friksjonsverdierMatriseDriftsklasseBru15persentil)):
    friksjonsverdierMatriseDriftsklasseBru15persentil[i] = np.asarray(friksjonsverdierListeDriftsklasseBru15persentil[i])
    friksjonsverdierMatriseDriftsklasseUtenfor15persentil[i] = np.asarray(friksjonsverdierListeDriftsklasseUtenfor15persentil[i])
    friksjonsverdierMatriseDriftsklasse15persentil[i] = np.asarray(friksjonsverdierListeDriftsklasse15persentil[i])
    friksjonsverdierMatriseDriftsklasse15persentil_mean[i] = np.mean(friksjonsverdierMatriseDriftsklasse15persentil[i])

friksjonsverdierMatriseDriftsklasseBru = [friksjonsverdierMatriseDkABru, friksjonsverdierMatriseDkB1Bru,
                                          friksjonsverdierMatriseDkB2Bru, friksjonsverdierMatriseDkB3Bru,
                                          friksjonsverdierMatriseDkCBru, friksjonsverdierMatriseDkDBru,
                                          friksjonsverdierMatriseDkEBru, friksjonsverdierMatriseDkAlleBru]
friksjonsverdierMatriseDriftsklasseUtenfor = [friksjonsverdierMatriseDkAUtenfor, friksjonsverdierMatriseDkB1Utenfor,
                                              friksjonsverdierMatriseDkB2Utenfor, friksjonsverdierMatriseDkB3Utenfor,
                                              friksjonsverdierMatriseDkCUtenfor, friksjonsverdierMatriseDkDUtenfor,
                                              friksjonsverdierMatriseDkEUtenfor, friksjonsverdierMatriseDkAlleUtenfor]
friksjonsverdierMatriseDriftsklasse = [friksjonsverdierMatriseDkA, friksjonsverdierMatriseDkB1,
                                       friksjonsverdierMatriseDkB2, friksjonsverdierMatriseDkB3,
                                       friksjonsverdierMatriseDkC, friksjonsverdierMatriseDkC,
                                       friksjonsverdierMatriseDkE, friksjonsverdierMatriseDkAlle]

DkA5persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru5persentil[0], friksjonsverdierMatriseDriftsklasseUtenfor5persentil[0], equal_var=True, alternative='two-sided')
DkB15persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru5persentil[1], friksjonsverdierMatriseDriftsklasseUtenfor5persentil[1], equal_var=True, alternative='two-sided')
DkB25persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru5persentil[2], friksjonsverdierMatriseDriftsklasseUtenfor5persentil[2], equal_var=True, alternative='two-sided')
DkB35persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru5persentil[3], friksjonsverdierMatriseDriftsklasseUtenfor5persentil[3], equal_var=True, alternative='two-sided')
DkC5persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru5persentil[4], friksjonsverdierMatriseDriftsklasseUtenfor5persentil[4], equal_var=True, alternative='two-sided')
DkD5persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru5persentil[5], friksjonsverdierMatriseDriftsklasseUtenfor5persentil[5], equal_var=True, alternative='two-sided')
DkE5persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru5persentil[6], friksjonsverdierMatriseDriftsklasseUtenfor5persentil[6], equal_var=True, alternative='two-sided')
DkAlle5persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru5persentil[7], friksjonsverdierMatriseDriftsklasseUtenfor5persentil[7], equal_var=True, alternative='two-sided')

DkA15persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru15persentil[0], friksjonsverdierMatriseDriftsklasseUtenfor15persentil[0], equal_var=True, alternative='two-sided')
DkB115persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru15persentil[1], friksjonsverdierMatriseDriftsklasseUtenfor15persentil[1], equal_var=True, alternative='two-sided')
DkB215persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru15persentil[2], friksjonsverdierMatriseDriftsklasseUtenfor15persentil[2], equal_var=True, alternative='two-sided')
DkB315persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru15persentil[3], friksjonsverdierMatriseDriftsklasseUtenfor15persentil[3], equal_var=True, alternative='two-sided')
DkC15persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru15persentil[4], friksjonsverdierMatriseDriftsklasseUtenfor15persentil[4], equal_var=True, alternative='two-sided')
DkD15persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru15persentil[5], friksjonsverdierMatriseDriftsklasseUtenfor15persentil[5], equal_var=True, alternative='two-sided')
DkE15persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru15persentil[6], friksjonsverdierMatriseDriftsklasseUtenfor15persentil[6], equal_var=True, alternative='two-sided')
DkAlle15persentilSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru15persentil[7], friksjonsverdierMatriseDriftsklasseUtenfor15persentil[7], equal_var=True, alternative='two-sided')

DkAGjennomsnittSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru[0], friksjonsverdierMatriseDriftsklasseUtenfor[0], equal_var=True, alternative='two-sided')
DkB1GjennomsnittSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru[1], friksjonsverdierMatriseDriftsklasseUtenfor[1], equal_var=True, alternative='two-sided')
DkB2GjennomsnittSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru[2], friksjonsverdierMatriseDriftsklasseUtenfor[2], equal_var=True, alternative='two-sided')
DkB3GjennomsnittSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru[3], friksjonsverdierMatriseDriftsklasseUtenfor[3], equal_var=True, alternative='two-sided')
DkCGjennomsnittSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru[4], friksjonsverdierMatriseDriftsklasseUtenfor[4], equal_var=True, alternative='two-sided')
DkDGjennomsnittSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru[5], friksjonsverdierMatriseDriftsklasseUtenfor[5], equal_var=True, alternative='two-sided')
DkEGjennomsnittSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru[6], friksjonsverdierMatriseDriftsklasseUtenfor[6], equal_var=True, alternative='two-sided')
DkAlleGjennomsnittSignifikansInd = scipy.stats.ttest_ind(friksjonsverdierMatriseDriftsklasseBru[7], friksjonsverdierMatriseDriftsklasseUtenfor[7], equal_var=True, alternative='two-sided')


# Gir informasjon om datasettet
print('\nInformasjon om datagrunnlaget:')
print('Antall filer med målepunkter maksimum 100 meter fra ei bru: {}'.format(len(listeFilerMatriser)))
print('Antall bruer med målepunkter maksimum 100 meter fra ei bru: {}'.format(len(listeBruerMatriser)))
print('Antall bruer med friksjon målt på selve bruene: {}'.format(antallBruer))
print('Antall innenfor 100 meter av ei bru: {}'.format(antallBrupunkter))
print('Antall målepunkter mellom klokken 08:00 og 20:00: {}, og mellom klokken 20:00 og 08:00: {}'.format(len(klokkeslett8_20), len(klokkeslett20_8)))
print('Fordeling av målepunkter på formen *fylkesnummer*: *antall målepunkter*')
print(Counter(fylkesnummerListe))
print('\n')

# Gir informasjon om tilfeller hvor brua har lavere friksjon enn vegen rundt
print('Informasjon om målepunkter hvor brua har lavere friksjon enn målepunktene rundt bra:')
print('Antall tilfeller hvor differansen mellom laveste friksjonsverdi på bru og rundt bru er mellom 0,00 og 0,05: {}'.format(friksjonLavestPaaBruTeller0))
print('Lavest friksjonsverdi: {}, nest lavest friksjonsverdi: {}'.format(minBruFriksjonListe0[0], minBruFriksjonListe0[1]))
print('Antall tilfeller hvor differansen mellom laveste friksjonsverdi på bru og rundt bru er mellom 0,05 og 0,10: {}'.format(friksjonLavestPaaBruTeller1))
print('Lavest friksjonsverdi: {}, nest lavest friksjonsverdi: {}'.format(minBruFriksjonListe1[0], minBruFriksjonListe1[1]))
print('Antall tilfeller hvor differansen mellom laveste friksjonsverdi på bru og rundt bru er mellom 0,10 og 0,15: {}'.format(friksjonLavestPaaBruTeller2))
print('Lavest friksjonsverdi: {}, nest lavest friksjonsverdi: {}'.format(minBruFriksjonListe2[0], minBruFriksjonListe2[1]))
print('Antall tilfeller hvor differansen mellom laveste friksjonsverdi på bru og rundt bru er høyere enn  0,15: {}'.format(friksjonLavestPaaBruTeller3))
print('Lavest friksjonsverdi: {}, nest lavest friksjonsverdi: {}\n'.format(minBruFriksjonListe3[0], minBruFriksjonListe3[1]))

# Gir informasjon om 95-persentil for laveste friksjonsverdi og gjennomsnittlig friksjonsverdi
print('Informasjon om vinterdriftsklasser:')
print('Alle Dk, Kun bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkAlleBru, 5),
    np.percentile(friksjonsverdierMatriseDkAlleBru, 15),
    np.average(friksjonsverdierMatriseDkAlleBru),
    len(friksjonsverdierListeDriftsklasseAlleBru)))
print('Alle Dk, Utenfor bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkAlleUtenfor, 5),
    np.percentile(friksjonsverdierMatriseDkAlleUtenfor, 15),
    np.average(friksjonsverdierMatriseDkAlleUtenfor),
    len(friksjonsverdierListeDriftsklasseAlleUtenfor)))
print('Alle Dk, Alle målepunkter, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkAlle, 5),
    np.percentile(friksjonsverdierMatriseDkAlle, 15),
    np.average(friksjonsverdierMatriseDkAlle),
    len(friksjonsverdierListeDriftsklasseAlle)))
print('DkA, Kun bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, p-verdi: {}, n: {}'.format(
    np.percentile(friksjonsverdierListeDkABru, 5),
    np.percentile(friksjonsverdierListeDkABru, 15),
    np.average(friksjonsverdierListeDkABru),
    DkASignifikans[1],
    len(friksjonsverdierListeDkABru)))
print('DkA, Utenfor bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkAUtenfor, 5),
    np.percentile(friksjonsverdierMatriseDkAUtenfor, 15),
    np.average(friksjonsverdierMatriseDkAUtenfor),
    len(friksjonsverdierListeDkAUtenfor)))
print('DkA, Alle målepunkter, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkA, 5),
    np.percentile(friksjonsverdierMatriseDkA, 15),
    np.average(friksjonsverdierMatriseDkA),
    len(friksjonsverdierListeDkA)))
print('DkB høy, Kun bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, p-verdi: {}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB1Bru, 5),
    np.percentile(friksjonsverdierMatriseDkB1Bru, 15),
    np.average(friksjonsverdierMatriseDkB1Bru),
    DkB1Signifikans[1],
    len(friksjonsverdierListeDkB1Bru)))
print('DkB høy, Utenfor bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB1Utenfor, 5),
    np.percentile(friksjonsverdierMatriseDkB1Utenfor, 15),
    np.average(friksjonsverdierMatriseDkB1Utenfor),
    len(friksjonsverdierListeDkB1Utenfor)))
print('DkB høy, Alle målepunkter, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB1, 5),
    np.percentile(friksjonsverdierMatriseDkB1, 15),
    np.average(friksjonsverdierMatriseDkB1),
    len(friksjonsverdierListeDkB1)))
print('DkB middels, Kun bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, p-verdi: {}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB2Bru, 5),
    np.percentile(friksjonsverdierMatriseDkB2Bru, 15),
    np.average(friksjonsverdierMatriseDkB2Bru),
    DkB2Signifikans[1],
    len(friksjonsverdierListeDkB2Bru)))
print('DkB middels, Utenfor bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB2Utenfor, 5),
    np.percentile(friksjonsverdierMatriseDkB2Utenfor, 15),
    np.average(friksjonsverdierMatriseDkB2Utenfor),
    len(friksjonsverdierListeDkB2Utenfor)))
print('DkB middels, Alle målepunkter, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB2, 5),
    np.percentile(friksjonsverdierMatriseDkB2, 15),
    np.average(friksjonsverdierMatriseDkB2),
    len(friksjonsverdierListeDkB2)))
print('DkB lav, Kun bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, p-verdi: {}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB3Bru, 5),
    np.percentile(friksjonsverdierMatriseDkB3Bru, 15),
    np.average(friksjonsverdierMatriseDkB3Bru),
    DkB3Signifikans[1],
    len(friksjonsverdierListeDkB3Bru)))
print('DkB lav, Utenfor bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB3Utenfor, 5),
    np.percentile(friksjonsverdierMatriseDkB3Utenfor, 15),
    np.average(friksjonsverdierMatriseDkB3Utenfor),
    len(friksjonsverdierListeDkB3Utenfor)))
print('DkB lav, Alle målepunkter, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkB3, 5),
    np.percentile(friksjonsverdierMatriseDkB3, 15),
    np.average(friksjonsverdierMatriseDkB3),
    len(friksjonsverdierListeDkB3)))
print('DkC, Kun bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, p-verdi: {}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkCBru, 5),
    np.percentile(friksjonsverdierMatriseDkCBru, 15),
    np.average(friksjonsverdierMatriseDkCBru),
    DkCSignifikans[1],
    len(friksjonsverdierListeDkCBru)))
print('DkC, Utenfor bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkCUtenfor, 5),
    np.percentile(friksjonsverdierMatriseDkCUtenfor, 15),
    np.average(friksjonsverdierMatriseDkCUtenfor),
    len(friksjonsverdierListeDkCUtenfor)))
print('DkC, Alle målepunkter, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkC, 5),
    np.percentile(friksjonsverdierMatriseDkC, 15),
    np.average(friksjonsverdierMatriseDkC),
    len(friksjonsverdierListeDkC)))
print('DkD, Kun bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, p-verdi: {}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkDBru, 5),
    np.percentile(friksjonsverdierMatriseDkDBru, 15),
    np.average(friksjonsverdierMatriseDkDBru),
    DkDSignifikans[1],
    len(friksjonsverdierListeDkDBru)))
print('DkD, Utenfor bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkDUtenfor, 5),
    np.percentile(friksjonsverdierMatriseDkDUtenfor, 15),
    np.average(friksjonsverdierMatriseDkDUtenfor),
    len(friksjonsverdierListeDkDUtenfor)))
print('DkD, Alle målepunkter, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkD, 5),
    np.percentile(friksjonsverdierMatriseDkD, 15),
    np.average(friksjonsverdierMatriseDkD),
    len(friksjonsverdierListeDkD)))
print('DkE, Kun bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, p-verdi: {}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkEBru, 5),
    np.percentile(friksjonsverdierMatriseDkEBru, 15),
    np.average(friksjonsverdierMatriseDkEBru),
    DkESignifikans[1],
    len(friksjonsverdierListeDkEBru)))
print('DkE, Utenfor bru, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkEUtenfor, 5),
    np.percentile(friksjonsverdierMatriseDkEUtenfor, 15),
    np.average(friksjonsverdierMatriseDkEUtenfor),
    len(friksjonsverdierListeDkEUtenfor)))
print('DkE, Alle målepunkter, 5-persentil: {:.2f}, 15-persentil: {:.2f}, Gjennomsnitt: {:.3f}, n: {}'.format(
    np.percentile(friksjonsverdierMatriseDkE, 5),
    np.percentile(friksjonsverdierMatriseDkE, 15),
    np.average(friksjonsverdierMatriseDkE),
    len(friksjonsverdierListeDkE)))

# Gir informasjon om noen av 5-persentilene på bru er signifikant høyere enn punktene forøvrig for hver vinterdriftsklasse
print('\nVurdering av signifikans, Independent t-test:')
print('5-persentiler:')
print('Vinterdriftsklasse A sin 5-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkA5persentilSignifikansInd[1]))
print('Vinterdriftsklasse B, høy sin 5-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB15persentilSignifikansInd[1]))
print('Vinterdriftsklasse B, middels sin 5-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB25persentilSignifikansInd[1]))
print('Vinterdriftsklasse B, lav sin 5-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB35persentilSignifikansInd[1]))
print('Vinterdriftsklasse C sin 5-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkC5persentilSignifikansInd[1]))
print('Vinterdriftsklasse D sin 5-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkD5persentilSignifikansInd[1]))
print('Vinterdriftsklasse E sin 5-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkE5persentilSignifikansInd[1]))
print('Vinterdriftsklasse Alle sin 5-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkAlle5persentilSignifikansInd[1]))
print('15-persentiler:')
print('Vinterdriftsklasse A sin 15-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkA15persentilSignifikansInd[1]))
print('Vinterdriftsklasse B, høy sin 15-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB115persentilSignifikansInd[1]))
print('Vinterdriftsklasse B, middels sin 15-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB215persentilSignifikansInd[1]))
print('Vinterdriftsklasse B, lav sin 15-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB315persentilSignifikansInd[1]))
print('Vinterdriftsklasse C sin 15-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkC15persentilSignifikansInd[1]))
print('Vinterdriftsklasse D sin 15-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkD15persentilSignifikansInd[1]))
print('Vinterdriftsklasse E sin 15-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkE15persentilSignifikansInd[1]))
print('Vinterdriftsklasse Alle sin 15-persentil har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkAlle15persentilSignifikansInd[1]))
print('Gjennomsnitt:')
print('Vinterdriftsklasse A sitt gjennomsnitt har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkAGjennomsnittSignifikansInd[1]))
print('Vinterdriftsklasse B, høy sitt gjennomsnitt har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB1GjennomsnittSignifikansInd[1]))
print('Vinterdriftsklasse B, middels sitt gjennomsnitt har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB2GjennomsnittSignifikansInd[1]))
print('Vinterdriftsklasse B, lav sitt gjennomsnitt har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkB3GjennomsnittSignifikansInd[1]))
print('Vinterdriftsklasse C sitt gjennomsnitt har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkCGjennomsnittSignifikansInd[1]))
print('Vinterdriftsklasse D sitt gjennomsnitt har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkDGjennomsnittSignifikansInd[1]))
print('Vinterdriftsklasse E sitt gjennomsnitt har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkEGjennomsnittSignifikansInd[1]))
print('Vinterdriftsklasse Alle sitt gjennomsnitt har p-verdi = {} for bru sammenlignet med alle punkter'.format(DkAlleGjennomsnittSignifikansInd[1]))


# Gir informasjon om brumaterialene
print('\nInformasjon om brumaterialer og hvor hyppig de forekommer blant 5-persentilen for friksjonsverdier til ulike vinterdriftsklasser:')
print('Vinterdrifsklasse A, 5-persentil:', Counter(bruMaterialeListeDkA5persentil))
print('Vinterdrifsklasse B1, 5-persentil:', Counter(bruMaterialeListeDkB15persentil))
print('Vinterdrifsklasse B2, 5-persentil:', Counter(bruMaterialeListeDkB25persentil))
print('Vinterdrifsklasse B3, 5-persentil:', Counter(bruMaterialeListeDkB35persentil))
print('Vinterdrifsklasse C, 5-persentil:', Counter(bruMaterialeListeDkC5persentil))
print('Vinterdrifsklasse D, 5-persentil:', Counter(bruMaterialeListeDkD5persentil))
print('Vinterdrifsklasse E, 5-persentil:', Counter(bruMaterialeListeDkE5persentil))
print('Alle forekomster:', Counter(bruMaterialeListeDriftsklasseAlleBru))

# Gir informasjon om brusettene med flest målepunkter
print('\nIdentifikasjon til de seks brusettene med flest målepunkter:')
print('Bru med flest punkter: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}'.format(lengst1[0][0], lengst1[0][13],
                                                                                       lengst1[0][1]))
print('Bru med 2. flest punkter: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}'.format(lengst2[0][0], lengst2[0][13],
                                                                                          lengst2[0][1]))
print('Bru med 3. flest punkter: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}'.format(lengst3[0][0], lengst3[0][13],
                                                                                          lengst3[0][1]))
print('Bru med 4. flest punkter: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}'.format(lengst4[0][0], lengst4[0][13],
                                                                                          lengst4[0][1]))
print('Bru med 5. flest punkter: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}'.format(lengst5[0][0], lengst5[0][13],
                                                                                          lengst5[0][1]))
print('Bru med 6. flest punkter: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}'.format(lengst6[0][0], lengst6[0][13],
                                                                                          lengst6[0][1]))

# Gir informasjon om brusettene med størst variasjon i friksjon
print('\nIdentifikasjon til de seks brusettene med størst variasjon i friksjon:')
print('Brusett 1: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}, Vinterdriftsklasse = {}'.format(bruSett[0][0][0],
                                                                                                    bruSett[0][0][13],
                                                                                                    bruSett[0][0][1],
                                                                                                    bruSett[0][5][4]))
print('Brusett 2: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}, Vinterdriftsklasse = {}'.format(bruSett[1][0][0],
                                                                                                    bruSett[1][0][13],
                                                                                                    bruSett[1][0][1],
                                                                                                    bruSett[1][5][4]))
print('Brusett 3: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}, Vinterdriftsklasse = {}'.format(bruSett[2][0][0],
                                                                                                    bruSett[2][0][13],
                                                                                                    bruSett[2][0][1],
                                                                                                    bruSett[2][5][4]))
print('Brusett 4: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}, Vinterdriftsklasse = {}'.format(bruSett[3][0][0],
                                                                                                    bruSett[3][0][13],
                                                                                                    bruSett[3][0][1],
                                                                                                    bruSett[3][5][4]))
print('Brusett 5: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}, Vinterdriftsklasse = {}'.format(bruSett[4][0][0],
                                                                                                    bruSett[4][0][13],
                                                                                                    bruSett[4][0][1],
                                                                                                    bruSett[4][5][4]))
print('Brusett 6: Filnavn = {}, Målt med {}, ID på bru i NVDB = {}, Vinterdriftsklasse = {}'.format(bruSett[5][0][0],
                                                                                                    bruSett[5][0][13],
                                                                                                    bruSett[5][0][1],
                                                                                                    bruSett[5][5][4]))

# Viser en figur over hvordan friksjon relativ til friksjonen på brua endrer seg med avstand fra brua uavhengig av vinterdriftsklasse
fig = plt.figure(figsize=(12, 6))
fig.suptitle('Endring i totalfriksjon for alle vinterdriftsklasser, n = {}'.format(len(friksjonsverdierListeDriftsklasseAlle)), fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.17, right=0.94, top=0.8, wspace=0.2, hspace=0.28)

x = avstanderTilBruListeDriftsklasse
y1 = relativFriksjonsverdierMedianListeDriftsklasse
y2 = relativFriksjonsverdierMinListeDriftsklasse

ax1 = fig.add_subplot(121)
ax2 = fig.add_subplot(122)

ax1.set_title('Endring i friksjonsverdi til målepunkter \n relativ til median friksjonsverdi på bru', fontsize=17)
ax1.scatter(x, y1, alpha=0.1)
ax1.set_ylabel('Endring i friksjon', fontsize=15)
ax1.set_xlabel('Avstand til bru [m]', fontsize=15)
ax1.tick_params(right=True, left=True, bottom=True)

ax2.set_title('Endring i friksjonsverdi til målepunkter \n relativ til minimum friksjonsverdi på bru', fontsize=17)
ax2.scatter(x, y2, alpha=0.1, c='purple')
ax2.set_ylabel('Endring i friksjon', fontsize=15)
ax2.set_xlabel('Avstand til bru [m]', fontsize=15)
ax2.tick_params(right=True, left=True, bottom=True)

ax1.set_xlim([-0.6, 101])
ax2.set_xlim([-0.6, 101])
ax1.set_ylim([-0.6, 0.6])
ax2.set_ylim([-0.6, 0.6])

tick_spacing = 0.1
ax1.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax2.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))

# plt.show()

# Viser en figur over hvordan friksjonsverdiene endrer seg med avstand til bru fordelt på de ulike vinterdriftsklassene, Klasse A og B
fig = plt.figure(figsize=(12, 10))
fig.suptitle('Endring i totalfriksjon fordelt på vinterdriftsklasse', fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.1, right=0.94, top=0.9, wspace=0.2, hspace=0.28)

x1 = avstandListeDkA
x2 = avstandListeDkB1
x3 = avstandListeDkB2
x4 = avstandListeDkB3

y1 = relativFriksjonsverdierMedianListeDkA
y2 = relativFriksjonsverdierMedianListeDkB1
y3 = relativFriksjonsverdierMedianListeDkB2
y4 = relativFriksjonsverdierMedianListeDkB3

ax = fig.add_subplot(221)
ax2 = fig.add_subplot(222)
ax3 = fig.add_subplot(223)
ax4 = fig.add_subplot(224)

ax.set_title('Vinterdriftsklasse A, n = {}'.format(len(friksjonsverdierListeDkA)), fontsize=17)
ax.scatter(x1, y1, alpha=0.1)
ax.set_ylabel('Endring i friksjon', fontsize=15)
ax.set_xlabel('Avstand til bru [m]', fontsize=15)
ax.tick_params(right=True, left=True, bottom=True)

ax2.set_title('Vinterdriftsklasse B, høy, n = {}'.format(len(friksjonsverdierListeDkB1)), fontsize=17)
ax2.scatter(x2, y2, alpha=0.1)
ax2.set_ylabel('Endring i friksjon', fontsize=15)
ax2.set_xlabel('Avstand til bru [m]', fontsize=15)
ax2.tick_params(right=True, left=True, bottom=True)

ax3.set_title('Vinterdriftsklasse B, middels, n = {}'.format(len(friksjonsverdierListeDkB2)), fontsize=17)
ax3.scatter(x3, y3, alpha=0.1)
ax3.set_ylabel('Endring i friksjon', fontsize=15)
ax3.set_xlabel('Avstand til bru [m]', fontsize=15)
ax3.tick_params(right=True, left=True, bottom=True)

ax4.set_title('Vinterdriftsklasse B, lav, n = {}'.format(len(friksjonsverdierListeDkB3)), fontsize=17)
ax4.scatter(x4, y4, alpha=0.1)
ax4.set_ylabel('Endring i friksjon', fontsize=15)
ax4.set_xlabel('Avstand til bru [m]', fontsize=15)
ax4.tick_params(right=True, left=True, bottom=True)

ax.set_xlim([-1, 101])
ax2.set_xlim([-1, 101])
ax3.set_xlim([-1, 101])
ax4.set_xlim([-1, 101])
ax.set_ylim([-0.6, 0.6])
ax2.set_ylim([-0.6, 0.6])
ax3.set_ylim([-0.6, 0.6])
ax4.set_ylim([-0.6, 0.6])

tick_spacing = 0.1
ax.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax2.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax3.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax4.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))

# plt.show()

# Viser en figur over hvordan friksjonsverdiene endrer seg med avstand til bru fordelt på de ulike vinterdriftsklassene, Klasse C, D og E
fig = plt.figure(figsize=(12, 10))
fig.suptitle('Endring i totalfriksjon fordelt på vinterdriftsklasse', fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.1, right=0.94, top=0.9, wspace=0.51, hspace=0.28)

x5 = avstandListeDkC
x6 = avstandListeDkD
x7 = avstandListeDkE

y5 = relativFriksjonsverdierMedianListeDkC
y6 = relativFriksjonsverdierMedianListeDkD
y7 = relativFriksjonsverdierMedianListeDkE

gs = gridspec.GridSpec(2, 4)  # Benytter gridspec fremfor add_subplot for å sentrere den tredje grafen i figuren.
ax5 = plt.subplot(gs[0, 0:2])
ax6 = plt.subplot(gs[0, 2:])
ax7 = plt.subplot(gs[1, 1:3])

ax5.set_title('Vinterdriftsklasse C, n = {}'.format(len(friksjonsverdierListeDkC)), fontsize=17)
ax5.scatter(x5, y5, alpha=0.1)
ax5.set_ylabel('Endring i friksjon', fontsize=15)
ax5.set_xlabel('Avstand til bru [m]', fontsize=15)
ax5.tick_params(right=True, left=True, bottom=True)

ax6.set_title('Vinterdriftsklasse D, n = {}'.format(len(friksjonsverdierListeDkD)), fontsize=17)
ax6.scatter(x6, y6, alpha=0.1)
ax6.set_ylabel('Endring i friksjon', fontsize=15)
ax6.set_xlabel('Avstand til bru [m]', fontsize=15)
ax6.tick_params(right=True, left=True, bottom=True)

ax7.set_title('Vinterdriftsklasse E, n = {}'.format(len(friksjonsverdierListeDkE)), fontsize=17)
ax7.scatter(x7, y7, alpha=0.1)
ax7.set_ylabel('Endring i friksjon', fontsize=15)
ax7.set_xlabel('Avstand til bru [m]', fontsize=15)
ax7.tick_params(right=True, left=True, bottom=True)

ax5.set_xlim([-1, 101])
ax7.set_xlim([-1, 101])
ax6.set_xlim([-1, 101])
ax5.set_ylim([-0.6, 0.6])
ax6.set_ylim([-0.6, 0.6])
ax7.set_ylim([-0.6, 0.6])

tick_spacing = 0.1
ax5.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax6.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax7.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))

# plt.show()

# Lager en figur med temperatur og relativ friksjon
fig = plt.figure(figsize=(12, 6))
fig.suptitle('Endring i totalfriksjon avhengig av temperatur for alle målepunkter, n = {}'.format(
    len(relativFriksjonsverdierMedianListe)), fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.17, right=0.94, top=0.8, wspace=0.2, hspace=0.28)

x1 = luftTemperaturListe
x2 = vegTemperaturListe
y = relativFriksjonsverdierMedianListe

ax = fig.add_subplot(121)
ax2 = fig.add_subplot(122)

ax.set_title('Endring i friksjonsverdi avhengig av \n lufttemperatur', fontsize=17)
ax.scatter(x1, y, alpha=0.1)
ax.set_ylabel('Endring i friksjon', fontsize=15)
ax.set_xlabel('Lufttemperatur ['u'\u2103'']', fontsize=15)
ax.tick_params(right=True, left=True, bottom=True)

ax2.set_title('Endring i friksjonsverdi avhengig av \n vegoverflatetemperatur', fontsize=17)
ax2.scatter(x2, y, alpha=0.1)
ax2.set_ylabel('Endring i friksjon', fontsize=15)
ax2.set_xlabel('Vegoverflatetemperatur ['u'\u2103'']', fontsize=15)
ax2.tick_params(right=True, left=True, bottom=True)

ax.set_xlim([-25, 20])
ax2.set_xlim([-25, 20])
ax.set_ylim([-0.6, 0.6])
ax2.set_ylim([-0.6, 0.6])

tick_spacing = 0.1
ax1.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax2.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))

# plt.show()

# Lager en figur med temperatur og målt friksjon på bru
fig = plt.figure(figsize=(12, 6))
fig.suptitle('Totalfriksjonsverdi på bru avhengig av temperatur målt på bru, n = {}'.format(len(friksjonsverdierPaaBruListe)),
             fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.17, right=0.94, top=0.8, wspace=0.2, hspace=0.28)

x1 = luftTemperaturPaaBruListe
x2 = vegTemperaturPaaBruListe
y = friksjonsverdierPaaBruListe

ax = fig.add_subplot(121)
ax2 = fig.add_subplot(122)

ax.set_title('Friksjonsverdi på bru avhengig av \n lufttemperatur', fontsize=17)
ax.scatter(x1, y, alpha=0.1, c='deepskyblue')
ax.set_ylabel('Friksjonsverdi', fontsize=15)
ax.set_xlabel('Lufttemperatur ['u'\u2103'']', fontsize=15)
ax.tick_params(right=True, left=True, bottom=True)

ax2.set_title('Friksjonsverdi på bru avhengig av \n vegovertemperatur', fontsize=17)
ax2.scatter(x2, y, alpha=0.1, c='darkred')
ax2.set_ylabel('Friksjonsverdi', fontsize=15)
ax2.set_xlabel('Vegoverflatetemperatur ['u'\u2103'']', fontsize=15)
ax2.tick_params(right=True, left=True, bottom=True)

ax.set_xlim([-25, 20])
ax2.set_xlim([-25, 20])

tick_spacing = 0.1
ax.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax2.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))

# plt.show()

# Lager en figur som viser hvordan vegoverflatetemperaturen endres med avstand til bru
fig = plt.figure(figsize=(12, 6))
fig.suptitle(
    'Endring i vegoverflatetemperatur med avstand til bru sammenlignet \n med median vegoverflatetemperatur på bru, n = {}'.format(
        len(relativVegTemperaturListe)), fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.17, right=0.94, top=0.8, wspace=0.2, hspace=0.28)

gs = gridspec.GridSpec(1, 4)  # Benytter gridspec fremfor add_subplot for å sentrere den tredje grafen i figuren.
ax = plt.subplot(gs[0, 1:3])
ax.set_ylabel('Endring i vegoverflatetemperatur ['u'\u2103'']', fontsize=15)
ax.set_xlabel('Avstand til bru[m]', fontsize=15)
ax.scatter(avstanderTilBruListe, relativVegTemperaturListe, alpha=0.1, c='darkred')
ax.tick_params(right=True, left=True, bottom=True)

tick_spacing = 1
ax.yaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))

# plt.show()

# Lager en figur som viser hvordan friksjonsverdi varierer med luftfuktighet
fig = plt.figure(figsize=(12, 6))
fig.suptitle('Totalfriksjonsverdi avhengig av luftfuktighet', fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.17, right=0.94, top=0.8, wspace=0.2, hspace=0.28)

x1_1 = luftfuktighetLavTemperaturPaaBruListe
y1_1 = luftfuktighetLavTemperaturPaaBruFriksjonsverdierListe
x1_2 = luftfuktighetHoyTemperaturPaaBruListe
y1_2 = luftfuktighetHoyTemperaturPaaBruFriksjonsverdierListe
x2_1 = luftfuktighetLavTemperaturUtenforBruListe
y2_1 = luftfuktighetLavTemperaturUtenforBruFriksjonsverdierListe
x2_2 = luftfuktighetHoyTemperaturUtenforBruListe
y2_2 = luftfuktighetHoyTemperaturUtenforBruFriksjonsverdierListe

z1 = np.polyfit(x1_1, y1_1, 1)
z2 = np.polyfit(x2_1, y2_1, 1)
p1 = np.poly1d(z1)
p2 = np.poly1d(z2)

ax = fig.add_subplot(121)
ax2 = fig.add_subplot(122)

ax.set_title('Friksjonsverdi på bru avhengig av \n luftfuktighet, n = {}'.format(len(x1_1) + len(x1_2)), fontsize=17)
ax.scatter(x1_1, y1_1, c='cyan', label='T'u'\u2103'' 'u'\u2264'' 0'u'\u2103')
ax.scatter(x1_2, y1_2, c='red', label='T'u'\u2103''  > 0'u'\u2103')
ax.plot(x1_1, p1(x1_1), c='black', label='Trend')
ax.set_ylabel('Friksjonsverdi', fontsize=15)
ax.set_xlabel('Luftfuktighet [%]', fontsize=15)
ax.tick_params(right=True, left=True, bottom=True)

ax2.set_title('Friksjonsverdi utenfor bru avhengig av \n luftfuktighet, n = {}'.format(len(x2_1) + len(x2_2)),
              fontsize=17)
ax2.scatter(x2_1, y2_1, c='cyan')
ax2.scatter(x2_2, y2_2, c='red')
ax2.plot(x2_1, p2(x2_1), c='black')
ax2.set_ylabel('Friksjonsverdi', fontsize=15)
ax2.set_xlabel('Luftfuktighet [%]', fontsize=15)
ax2.tick_params(right=True, left=True, bottom=True)

ax.set_ylim([0, 0.6])
ax2.set_ylim([0, 0.6])

fig.legend(loc=8, ncol=3, fontsize=15)

# plt.show()

# Lager en figur som viser de seks bruene med flest målepunkter og hvordan friksjonen varierer for dem
fig = plt.figure(figsize=(12, 12))
fig.suptitle('Utvalg 1: Datasett med flest målepunkter og deres totalfriksjonsverdier', fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.11, right=0.94, top=0.9, wspace=0.2, hspace=0.5)

ax = fig.add_subplot(321)
ax2 = fig.add_subplot(322)
ax3 = fig.add_subplot(323)
ax4 = fig.add_subplot(324)
ax5 = fig.add_subplot(325)
ax6 = fig.add_subplot(326)

ax.set_title('Sett1, brulengde = {}m'.format(lengst1[0][10]).replace(".", ","), fontsize=17)
ax.set_ylabel('Friksjonsverdi', fontsize=15)
ax.set_xlabel('Nummer på målepunkt', fontsize=15)
ax.scatter(xAkseLengst1, yAkseLengst1, c='silver', label='Målepunkt utenfor bru')
ax.scatter(xAkseBruLengst1, yAkseBruLengst1, c='coral', label='Målepunkt på bru')
ax.tick_params(right=True, left=True, bottom=True)

ax2.set_title('Sett2, brulengde = {}m'.format(lengst2[0][10]).replace(".", ","), fontsize=17)
ax2.set_ylabel('Friksjonsverdi', fontsize=15)
ax2.set_xlabel('Nummer på målepunkt', fontsize=15)
ax2.scatter(xAkseLengst2, yAkseLengst2, c='silver')
ax2.scatter(xAkseBruLengst2, yAkseBruLengst2, c='coral')
ax2.tick_params(right=True, left=True, bottom=True)

ax3.set_title('Sett3, brulengde = {}m'.format(lengst3[0][10]).replace(".", ","), fontsize=17)
ax3.set_ylabel('Friksjonsverdi', fontsize=15)
ax3.set_xlabel('Nummer på målepunkt', fontsize=15)
ax3.scatter(xAkseLengst3, yAkseLengst3, c='silver')
ax3.scatter(xAkseBruLengst3, yAkseBruLengst3, c='coral')
ax3.tick_params(right=True, left=True, bottom=True)

ax4.set_title('Sett4, brulengde = {}m'.format(lengst4[0][10]).replace(".", ","), fontsize=17)
ax4.set_ylabel('Friksjonsverdi', fontsize=15)
ax4.set_xlabel('Nummer på målepunkt', fontsize=15)
ax4.scatter(xAkseLengst4, yAkseLengst4, c='silver')
ax4.scatter(xAkseBruLengst4, yAkseBruLengst4, c='coral')
ax4.tick_params(right=True, left=True, bottom=True)

ax5.set_title('Sett5, brulengde = {}m'.format(lengst5[0][10]).replace(".", ","), fontsize=17)
ax5.set_ylabel('Friksjonsverdi', fontsize=15)
ax5.set_xlabel('Nummer på målepunkt', fontsize=15)
ax5.scatter(xAkseLengst5, yAkseLengst5, c='silver')
ax5.scatter(xAkseBruLengst5, yAkseBruLengst5, c='coral')
ax5.tick_params(right=True, left=True, bottom=True)

ax6.set_title('Sett6, brulengde = {}m'.format(lengst6[0][10]).replace(".", ","), fontsize=17)
ax6.set_ylabel('Friksjonsverdi', fontsize=15)
ax6.set_xlabel('Nummer på målepunkt', fontsize=15)
ax6.scatter(xAkseLengst6, yAkseLengst6, c='silver')
ax6.scatter(xAkseBruLengst6, yAkseBruLengst6, c='coral')
ax6.tick_params(right=True, left=True, bottom=True)

ax.set_ylim([0, 0.6])
ax2.set_ylim([0, 0.6])
ax3.set_ylim([0, 0.6])
ax4.set_ylim([0, 0.6])
ax5.set_ylim([0, 0.6])
ax6.set_ylim([0, 0.6])

fig.legend(loc=8, ncol=2, fontsize=15)

# plt.show()

# Lager en figur som viser de seks bruene med størst variasjon i friksjon på og rundt bru
fig = plt.figure(figsize=(12, 15))
fig.suptitle('Utvalg 2: Datasett med størst variasjon i totalfriksjon målt på og utenfor bru', fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.09, right=0.94, top=0.92, wspace=0.32, hspace=0.35)

ax1 = fig.add_subplot(321)
ax2 = fig.add_subplot(322)
ax3 = fig.add_subplot(323)
ax4 = fig.add_subplot(324)
ax5 = fig.add_subplot(325)
ax6 = fig.add_subplot(326)

ax1.set_title('Sett1, brulengde = {}m'.format(bruSett[0][0][10]).replace(".", ","), fontsize=17)
ax1.set_ylabel('Friksjonsverdi', fontsize=15)
ax1.set_xlabel('Nummer på målepunkt', fontsize=15)
ax1.scatter(brusettTall[0], bruSettFriksjon[0], c='silver', label='Målepunkt utenfor bru')
ax1.scatter(brusettTallBru[0], bruSettFriksjonBru[0], c='coral', label='Målepunkt på bru')
ax1.tick_params(axis='y', bottom=True)
ax1_1 = ax1.twinx()
ax1_1.plot(brusettTall[0], bruSettVegoverflate[0], c='darkred', label='T'u'\u2103')
ax1_1.set_ylabel('Tetemperatur ['u'\u2103'']', c='darkred', fontsize=15)
ax1_1.tick_params(axis='y', labelcolor='darkred')

ax2.set_title('Sett2, brulengde = {}m'.format(bruSett[1][0][10]).replace(".", ","), fontsize=17)
ax2.set_ylabel('Friksjonsverdi', fontsize=15)
ax2.set_xlabel('Nummer på målepunkt', fontsize=15)
ax2.scatter(brusettTall[1], bruSettFriksjon[1], c='silver')
ax2.scatter(brusettTallBru[1], bruSettFriksjonBru[1], c='coral')
ax2.tick_params(axis='y', bottom=True)
ax2_1 = ax2.twinx()
ax2_1.plot(brusettTall[1], bruSettVegoverflate[1], c='darkred')
ax2_1.set_ylabel('Tetemperatur ['u'\u2103'']', c='darkred', fontsize=15)
ax2_1.tick_params(axis='y', labelcolor='darkred')

ax3.set_title('Sett3, brulengde = {}m'.format(bruSett[2][0][10]).replace(".", ","), fontsize=17)
ax3.set_ylabel('Friksjonsverdi', fontsize=15)
ax3.set_xlabel('Nummer på målepunkt', fontsize=15)
ax3.scatter(brusettTall[2], bruSettFriksjon[2], c='silver')
ax3.scatter(brusettTallBru[2], bruSettFriksjonBru[2], c='coral')
ax3.tick_params(axis='y', bottom=True)
ax3_1 = ax3.twinx()
ax3_1.plot(brusettTall[2], bruSettVegoverflate[2], c='darkred')
ax3_1.set_ylabel('Tetemperatur ['u'\u2103'']', c='darkred', fontsize=15)
ax3_1.tick_params(axis='y', labelcolor='darkred')

ax4.set_title('Sett4, brulengde = {}m'.format(bruSett[3][0][10]).replace(".", ","), fontsize=17)
ax4.set_ylabel('Friksjonsverdi', fontsize=15)
ax4.set_xlabel('Nummer på målepunkt', fontsize=15)
ax4.scatter(brusettTall[3], bruSettFriksjon[3], c='silver')
ax4.scatter(brusettTallBru[3], bruSettFriksjonBru[3], c='coral')
ax4.tick_params(axis='y', bottom=True)
ax4_1 = ax4.twinx()
ax4_1.plot(brusettTall[3], bruSettVegoverflate[3], c='darkred')
ax4_1.set_ylabel('Tetemperatur ['u'\u2103'']', c='darkred', fontsize=15)
ax4_1.tick_params(axis='y', labelcolor='darkred')

ax5.set_title('Sett5, brulengde = {}m'.format(bruSett[4][0][10]).replace(".", ","), fontsize=17)
ax5.set_ylabel('Friksjonsverdi', fontsize=15)
ax5.set_xlabel('Nummer på målepunkt', fontsize=15)
ax5.scatter(brusettTall[4], bruSettFriksjon[4], c='silver')
ax5.scatter(brusettTallBru[4], bruSettFriksjonBru[4], c='coral')
ax5.tick_params(axis='y', bottom=True)
ax5_1 = ax5.twinx()
ax5_1.plot(brusettTall[4], bruSettVegoverflate[4], c='darkred')
ax5_1.set_ylabel('Tetemperatur ['u'\u2103'']', c='darkred', fontsize=15)
ax5_1.tick_params(axis='y', labelcolor='darkred')

ax6.set_title('Sett6, brulengde = {}m'.format(bruSett[5][0][10]).replace(".", ","), fontsize=17)
ax6.set_ylabel('Friksjonsverdi', fontsize=15)
ax6.set_xlabel('Nummer på målepunkt', fontsize=15)
ax6.scatter(brusettTall[5], bruSettFriksjon[5], c='silver')
ax6.scatter(brusettTallBru[5], bruSettFriksjonBru[5], c='coral')
ax6.tick_params(axis='y', bottom=True)
ax6_1 = ax6.twinx()
ax6_1.plot(brusettTall[5], bruSettVegoverflate[5], c='darkred')
ax6_1.set_ylabel('Tetemperatur ['u'\u2103'']', c='darkred', fontsize=15)
ax6_1.tick_params(axis='y', labelcolor='darkred')

ax1.set_ylim([0, 0.6])
ax2.set_ylim([0, 0.6])
ax3.set_ylim([0, 0.6])
ax4.set_ylim([0, 0.6])
ax5.set_ylim([0, 0.6])
ax6.set_ylim([0, 0.6])
ax1_1.set_ylim([-5, 3])
ax2_1.set_ylim([-5, 3])
ax3_1.set_ylim([-5, 3])
ax4_1.set_ylim([-5, 3])
ax5_1.set_ylim([-5, 3])
ax6_1.set_ylim([-5, 3])
tick_spacing1 = 1
tick_spacing2 = 2
ax1.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing2))
ax2.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing2))
ax3.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing2))
ax4.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax5.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing2))
ax6.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing2))
fig.legend(loc=8, ncol=3, fontsize=15)

# plt.show()


# Densitetsfordeling til friksjonsverdiene
fig = plt.figure(figsize=(9, 6))
fig.suptitle('Densitetsfordeling til målepunktenes totalfriksjonsverdier', fontsize=20)
fig.subplots_adjust(left=0.08, bottom=0.19, right=0.94, top=0.9, wspace=0.32, hspace=0.35)
ax = fig.add_subplot(111)

x_verdier = np.linspace(0, 0.7)
densitet1 = gaussian_kde(friksjonsverdierMatriseDkAlle)
densitet1.covariance_factor = lambda: .5
densitet1._compute_covariance()
densitet2 = gaussian_kde(friksjonsverdierMatriseDkAlleBru)
densitet2.covariance_factor = lambda: .5
densitet2._compute_covariance()

ax.plot(x_verdier, densitet1(x_verdier), label='Alle')
ax.plot(x_verdier, densitet2(x_verdier), label='Kun bru')
ax.set_ylabel('Densitet', fontsize=15)
ax.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing = 0.05
ax.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax.set_xlim([0, 0.7])
ax.set_ylim([0, 5])
ax.tick_params(right=True, left=True, bottom=True)
fig.legend(loc=8, ncol=2, fontsize=15)

# plt.show()


# Gjennomsnitt og standardavvik til ulike vinterdriftsklasser
fig = plt.figure(figsize=(9, 6))
fig.suptitle('Gjennomsnitt og standardavvik til totalfriksjonsverdier \n avhengig av vinterdriftsklasse på og utenfor bru', fontsize=20)
fig.subplots_adjust(left=0.08, bottom=0.19, right=0.94, top=0.85, wspace=0.32, hspace=0.35)
ax = fig.add_subplot(111)

x = np.arange(8)
bredde = 0.4

plt.bar(x-0.2, gjennomsnittBru, bredde, yerr=standardavvikBru, color='coral', align='center', ecolor='black', capsize=10, label='Bru')
plt.bar(x+0.2, gjennomsnittUtenfor, bredde, yerr=standardavvikUtenfor, color='silver', align='center', ecolor='black', capsize=10, label='Utenfor')
plt.xticks(x, ['Alle', 'A', 'B, høy', 'B, middels', 'B, lav', 'C', 'D', 'E'])
plt.xlabel("Vinterdriftsklasser", fontsize=15)
plt.ylabel("Friksjonsverdi", fontsize=15)
fig.legend(loc=8, ncol=2, fontsize=15)

# plt.show()

# Densitetsfordeling til friksjonsverdiene
fig = plt.figure(figsize=(9, 6))
fig.suptitle('Densitetsfordeling til målepunktenes totalfriksjonsverdier', fontsize=20)
fig.subplots_adjust(left=0.08, bottom=0.19, right=0.94, top=0.9, wspace=0.32, hspace=0.35)
ax = fig.add_subplot(111)

x_verdier = np.linspace(0, 0.7)
densitet1 = gaussian_kde(friksjonsverdierMatriseDkAlle)
densitet1.covariance_factor = lambda: .5
densitet1._compute_covariance()
densitet2 = gaussian_kde(friksjonsverdierMatriseDkAlleBru)
densitet2.covariance_factor = lambda: .5
densitet2._compute_covariance()

ax.plot(x_verdier, densitet1(x_verdier), label='Alle')
ax.plot(x_verdier, densitet2(x_verdier), label='Kun bru')
ax.set_ylabel('Densitet', fontsize=15)
ax.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing = 0.05
ax.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax.set_xlim([0, 0.7])
ax.set_ylim([0, 5])
ax.tick_params(right=True, left=True, bottom=True)
fig.legend(loc=8, ncol=2, fontsize=15)

# plt.show()


# Gjennomsnitt og standardavvik til ulike vinterdriftsklasser
fig = plt.figure(figsize=(9, 6))
fig.suptitle('Gjennomsnitt og standardavvik til totalfriksjonsverdier \n avhengig av vinterdriftsklasse på og utenfor bru', fontsize=20)
fig.subplots_adjust(left=0.08, bottom=0.19, right=0.94, top=0.85, wspace=0.32, hspace=0.35)
ax = fig.add_subplot(111)

x = np.arange(8)
bredde = 0.4

plt.bar(x-0.2, gjennomsnittBru, bredde, yerr=standardavvikBru, color='coral', align='center', ecolor='black', capsize=10, label='Bru')
plt.bar(x+0.2, gjennomsnittUtenfor, bredde, yerr=standardavvikUtenfor, color='silver', align='center', ecolor='black', capsize=10, label='Utenfor')
plt.xticks(x, ['Alle', 'A', 'B, høy', 'B, middels', 'B, lav', 'C', 'D', 'E'])
plt.xlabel("Vinterdriftsklasser", fontsize=15)
plt.ylabel("Friksjonsverdi", fontsize=15)
fig.legend(loc=8, ncol=2, fontsize=15)

# plt.show()

fig = plt.figure(figsize=(12, 14))
fig.suptitle('Densitetsfordeling til totalfriksjonsverdiene for ulike vinterdriftsklasser', fontsize=20)
fig.subplots_adjust(left=0.06, bottom=0.09, right=0.94, top=0.92, wspace=0.23, hspace=0.43)

ax1 = fig.add_subplot(421)
ax1.set_title('Vinterdriftsklasse A', fontsize=17)
densitetUtenfor = gaussian_kde(friksjonsverdierMatriseDkAUtenfor)
densitetBru = gaussian_kde(friksjonsverdierMatriseDkABru)
x_verdier = np.linspace(0, 0.7)
densitetUtenfor.covariance_factor = lambda: .5
densitetUtenfor._compute_covariance()
densitetBru._compute_covariance()
ax1.plot(x_verdier, densitetUtenfor(x_verdier), c='grey', label='Målepunkt utenfor bru')
ax1.plot(x_verdier, densitetBru(x_verdier), c='coral', label='Målepunkt på bru')
ax1.set_ylabel('Densitet', fontsize=15)
ax1.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing1 = 0.1
tick_spacing2 = 0.05
ax1.set_xlim([0, 0.7])
ax1.set_ylim([0, 12])
ax1.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax1.xaxis.set_minor_locator(ticker.MultipleLocator(tick_spacing2))
ax1.xaxis.grid(True, which='minor')
ax1.grid()

ax2 = fig.add_subplot(422)
ax2.set_title('Vinterdriftsklasse B, høy', fontsize=17)
densitetUtenfor = gaussian_kde(friksjonsverdierMatriseDkB1Utenfor)
densitetBru = gaussian_kde(friksjonsverdierMatriseDkB1Bru)
x_verdier = np.linspace(0, 0.7)
densitetUtenfor.covariance_factor = lambda: .5
densitetUtenfor._compute_covariance()
densitetBru._compute_covariance()
ax2.plot(x_verdier, densitetUtenfor(x_verdier), c='grey')
ax2.plot(x_verdier, densitetBru(x_verdier), c='coral')
ax2.set_ylabel('Densitet', fontsize=15)
ax2.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing1 = 0.1
tick_spacing2 = 0.05
ax2.set_xlim([0, 0.7])
ax2.set_ylim([0, 12])
ax2.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax2.xaxis.set_minor_locator(ticker.MultipleLocator(tick_spacing2))
ax2.xaxis.grid(True, which='minor')
ax2.grid()

ax3 = fig.add_subplot(423)
ax3.set_title('Vinterdriftsklasse B, middels', fontsize=17)
densitetUtenfor = gaussian_kde(friksjonsverdierMatriseDkB2Utenfor)
densitetBru = gaussian_kde(friksjonsverdierMatriseDkB2Bru)
x_verdier = np.linspace(0, 0.7)
densitetUtenfor.covariance_factor = lambda: .5
densitetUtenfor._compute_covariance()
densitetBru._compute_covariance()
ax3.plot(x_verdier, densitetUtenfor(x_verdier), c='grey')
ax3.plot(x_verdier, densitetBru(x_verdier), c='coral')
ax3.set_ylabel('Densitet', fontsize=15)
ax3.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing1 = 0.1
tick_spacing2 = 0.05
ax3.set_xlim([0, 0.7])
ax3.set_ylim([0, 12])
ax3.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax3.xaxis.set_minor_locator(ticker.MultipleLocator(tick_spacing2))
ax3.xaxis.grid(True, which='minor')
ax3.grid()

ax4 = fig.add_subplot(424)
ax4.set_title('Vinterdriftsklasse B, lav', fontsize=17)
densitetUtenfor = gaussian_kde(friksjonsverdierMatriseDkB3Utenfor)
densitetBru = gaussian_kde(friksjonsverdierMatriseDkB3Bru)
x_verdier = np.linspace(0, 0.7)
densitetUtenfor.covariance_factor = lambda: .5
densitetUtenfor._compute_covariance()
densitetBru._compute_covariance()
ax4.plot(x_verdier, densitetUtenfor(x_verdier), c='grey')
ax4.plot(x_verdier, densitetBru(x_verdier), c='coral')
ax4.set_ylabel('Densitet', fontsize=15)
ax4.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing1 = 0.1
tick_spacing2 = 0.05
ax4.set_xlim([0, 0.7])
ax4.set_ylim([0, 12])
ax4.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax4.xaxis.set_minor_locator(ticker.MultipleLocator(tick_spacing2))
ax4.xaxis.grid(True, which='minor')
ax4.grid()

ax5 = fig.add_subplot(425)
ax5.set_title('Vinterdriftsklasse C', fontsize=17)
densitetUtenfor = gaussian_kde(friksjonsverdierMatriseDkCUtenfor)
densitetBru = gaussian_kde(friksjonsverdierMatriseDkCBru)
x_verdier = np.linspace(0, 0.7)
densitetUtenfor.covariance_factor = lambda: .5
densitetUtenfor._compute_covariance()
densitetBru._compute_covariance()
ax5.plot(x_verdier, densitetUtenfor(x_verdier), c='grey')
ax5.plot(x_verdier, densitetBru(x_verdier), c='coral')
ax5.set_ylabel('Densitet', fontsize=15)
ax5.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing1 = 0.1
tick_spacing2 = 0.05
ax5.set_xlim([0, 0.7])
ax5.set_ylim([0, 12])
ax5.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax5.xaxis.set_minor_locator(ticker.MultipleLocator(tick_spacing2))
ax5.xaxis.grid(True, which='minor')
ax5.grid()

ax6 = fig.add_subplot(426)
ax6.set_title('Vinterdriftsklasse D', fontsize=17)
densitetUtenfor = gaussian_kde(friksjonsverdierMatriseDkDUtenfor)
densitetBru = gaussian_kde(friksjonsverdierMatriseDkDBru)
x_verdier = np.linspace(0, 0.7)
densitetUtenfor.covariance_factor = lambda: .5
densitetUtenfor._compute_covariance()
densitetBru._compute_covariance()
ax6.plot(x_verdier, densitetUtenfor(x_verdier), c='grey')
ax6.plot(x_verdier, densitetBru(x_verdier), c='coral')
ax6.set_ylabel('Densitet', fontsize=15)
ax6.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing1 = 0.1
tick_spacing2 = 0.05
ax6.set_xlim([0, 0.7])
ax6.set_ylim([0, 12])
ax6.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax6.xaxis.set_minor_locator(ticker.MultipleLocator(tick_spacing2))
ax6.xaxis.grid(True, which='minor')
ax6.grid()

ax7 = fig.add_subplot(427)
ax7.set_title('Vinterdriftsklasse E', fontsize=17)
densitetUtenfor = gaussian_kde(friksjonsverdierMatriseDkEUtenfor)
densitetBru = gaussian_kde(friksjonsverdierMatriseDkEBru)
x_verdier = np.linspace(0, 0.7)
densitetUtenfor.covariance_factor = lambda: .5
densitetUtenfor._compute_covariance()
densitetBru._compute_covariance()
ax7.plot(x_verdier, densitetUtenfor(x_verdier), c='grey')
ax7.plot(x_verdier, densitetBru(x_verdier), c='coral')
ax7.set_ylabel('Densitet', fontsize=15)
ax7.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing1 = 0.1
tick_spacing2 = 0.05
ax7.set_xlim([0, 0.7])
ax7.set_ylim([0, 12])
ax7.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax7.xaxis.set_minor_locator(ticker.MultipleLocator(tick_spacing2))
ax7.xaxis.grid(True, which='minor')
ax7.grid()

ax8 = fig.add_subplot(428)
ax8.set_title('Uavhengig av vinterdriftsklasse', fontsize=17)
densitetUtenfor = gaussian_kde(friksjonsverdierMatriseDkAlleUtenfor)
densitetBru = gaussian_kde(friksjonsverdierMatriseDkAlleBru)
x_verdier = np.linspace(0, 0.7)
densitetUtenfor.covariance_factor = lambda: .5
densitetUtenfor._compute_covariance()
densitetBru._compute_covariance()
ax8.plot(x_verdier, densitetUtenfor(x_verdier), c='grey')
ax8.plot(x_verdier, densitetBru(x_verdier), c='coral')
ax8.set_ylabel('Densitet', fontsize=15)
ax8.set_xlabel('Friksjonsverdi', fontsize=15)
tick_spacing1 = 0.1
tick_spacing2 = 0.05
ax8.set_xlim([0, 0.7])
ax8.set_ylim([0, 12])
ax8.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing1))
ax8.xaxis.set_minor_locator(ticker.MultipleLocator(tick_spacing2))
ax8.xaxis.grid(True, which='minor')
ax8.grid()

fig.legend(loc=8, ncol=2, fontsize=15)

plt.show()
