import numpy as np
import matplotlib.pyplot as plt
import matplotlib.gridspec as gridspec
import matplotlib.ticker as ticker
import scipy.stats
from scipy.stats import gaussian_kde

# Oppgi sti til mappen hvor matrisen ligger lagret
sti = 'C:\\Programmering\\'
innSti = sti + 'Python\\BruMatrise.npy'

# Kolonne 0 = Filnavn
# Kolonne 1 = Bruas ID i NVDB
# Kolonne 2 = Målepunktets avstand til brua [m]
# Kolonne 3 = Målepunktets friksjonsverdi
# Kolonne 4 = Vegens vinterdriftsklasse ved målepunktet
# Kolonne 5 = Lufttemperatur [Celsius]
# Kolonne 6 = Vegoverflatetemperatur [Celsius]
# Kolonne 7 = Luftfuktighet [%] OBS, ofte utilgjengelig
# Kolonne 8 = Brutype
# Kolonne 9 = Brumateriale
# Kolonne 10 = Bruas totale lengde [m]
# Kolonne 11 = Bruas byggeår. OBS, ofte utilgjengelig
# Kolonne 12 = Vegens horisontalradius [m]
# Kolonne 13 = Utstyr brukt under målingen
# Kolonne 14 = Vegens referanse (navn)
# Kolonne 15 = Fylke
# Kolonne 16 = Året målingen ble utført
# Kolonne 17 = Måneden målingen ble utført
# Kolonne 18 = Dagen målingen ble utført
# Kolonne 19 = Klokkeslett målingen ble utført

matrise = np.load(innSti)  # Laster inn matrisen

# Splitter matrisen med all data opp i mindre matriser hvor hver fil har sin matrise
unikeFilnavnIndekser = np.unique(matrise[:, 0], True)[1]
listeFilerMatriser = []
for i in range(len(unikeFilnavnIndekser)):
    if i < len(unikeFilnavnIndekser) - 1:
        a = unikeFilnavnIndekser[i]
        b = unikeFilnavnIndekser[i + 1]
        listeFilerMatriser.append(matrise[a:b, :])
    else:
        a = unikeFilnavnIndekser[i]
        b = len(matrise)
        listeFilerMatriser.append(matrise[a:b, :])

# Splitter fil-matrisene opp slik at hver ny matrise inneholder alle målepunktene forbundet til ei bestemt bru
listeBruerMatriser = []
for filerMatriser in listeFilerMatriser:
    bruIDerIndekser = np.sort(np.unique(filerMatriser[:, 1], True)[1])
    if len(bruIDerIndekser) > 0:
        for i in range(len(bruIDerIndekser)):
            if i < len(bruIDerIndekser) - 1:
                a = bruIDerIndekser[i]
                b = bruIDerIndekser[i + 1]
                listeBruerMatriser.append(filerMatriser[a:b, :])
            else:
                a = bruIDerIndekser[i]
                b = len(filerMatriser)
                listeBruerMatriser.append(filerMatriser[a:b, :])

gaulaBru = []
gaulaUtenfor = []
gaulaAlle = []
ikkeGaulaBru = []
ikkeGaulaUtenfor = []
ikkeGaulaAlle = []
for matriseM in listeBruerMatriser:
    for linje in matriseM:
        if linje[4] == 'DkB, høy':
            if linje[1] == '356850353':
                gaulaAlle.append(float(linje[3]))
                if linje[2] == '0.0':
                    gaulaBru.append(float(linje[3]))
                else:
                    gaulaUtenfor.append(float(linje[3]))
            else:
                ikkeGaulaAlle.append(float(linje[3]))
                if linje[2] == '0.0':
                    ikkeGaulaBru.append(float(linje[3]))
                else:
                    ikkeGaulaUtenfor.append(float(linje[3]))

gaulaBru.sort()
gaulaUtenfor.sort()
gaulaAlle.sort()
ikkeGaulaBru.sort()
ikkeGaulaUtenfor.sort()
ikkeGaulaAlle.sort()

gaulaBruFriksjon = np.asarray(gaulaBru)
gaulaUtenforFriksjon = np.asarray(gaulaUtenfor)
gaulaAlleFriksjon = np.asarray(gaulaAlle)
ikkeGaulaBruFriksjon = np.asarray(ikkeGaulaBru)
ikkeGaulaUtenforFriksjon = np.asarray(ikkeGaulaUtenfor)
ikkeGaulaAlleFriksjon = np.asarray(ikkeGaulaAlle)

gaulaBru5persentil = np.percentile(gaulaBruFriksjon, 5)
gaulaUtenfor5persentil = np.percentile(gaulaUtenforFriksjon, 5)
gaulaAlle5persentil = np.percentile(gaulaAlleFriksjon, 5)
gaulaBru15persentil = np.percentile(gaulaBruFriksjon, 15)
gaulaUtenfor15persentil = np.percentile(gaulaUtenforFriksjon, 15)
gaulaAlle15persentil = np.percentile(gaulaAlleFriksjon, 15)
gaulaBruGjennomsnitt = np.mean(gaulaBruFriksjon)
gaulaUtenforGjennomsnitt = np.mean(gaulaUtenforFriksjon)
gaulaAlleGjennomsnitt = np.mean(gaulaAlleFriksjon)
ikkeGaulaBru5persentil = np.percentile(ikkeGaulaBruFriksjon, 5)
ikkeGaulaUtenfor5persentil = np.percentile(ikkeGaulaUtenforFriksjon, 5)
ikkeGaulaAlle5persentil = np.percentile(ikkeGaulaAlleFriksjon, 5)
ikkeGaulaBru15persentil = np.percentile(ikkeGaulaBruFriksjon, 15)
ikkeGaulaUtenfor15persentil = np.percentile(ikkeGaulaUtenforFriksjon, 15)
ikkeGaulaAlle15persentil = np.percentile(ikkeGaulaAlleFriksjon, 15)
ikkeGaulaBruGjennomsnitt = np.mean(ikkeGaulaBruFriksjon)
ikkeGaulaUtenforGjennomsnitt = np.mean(ikkeGaulaUtenforFriksjon)
ikkeGaulaAlleGjennomsnitt = np.mean(ikkeGaulaAlleFriksjon)

midlertidigListe = []
for i in range(round(len(gaulaBruFriksjon)*0.05)):
    midlertidigListe.append(gaulaBruFriksjon[i])
gaulaBruFriksjon5persentilListe = midlertidigListe
midlertidigListe = []
for i in range(round(len(gaulaUtenforFriksjon)*0.05)):
    midlertidigListe.append(gaulaUtenforFriksjon[i])
gaulaUtenforFriksjon5persentilListe = midlertidigListe
midlertidigListe = []
for i in range(round(len(gaulaBruFriksjon)*0.15)):
    midlertidigListe.append(gaulaBruFriksjon[i])
gaulaBruFriksjon15persentilListe = midlertidigListe
midlertidigListe = []
for i in range(round(len(gaulaUtenforFriksjon)*0.15)):
    midlertidigListe.append(gaulaUtenforFriksjon[i])
gaulaUtenforFriksjon15persentilListe = midlertidigListe

midlertidigListe = []
for i in range(round(len(ikkeGaulaBruFriksjon)*0.05)):
    midlertidigListe.append(ikkeGaulaBruFriksjon[i])
ikkeGaulaBruFriksjon5persentilListe = midlertidigListe
midlertidigListe = []
for i in range(round(len(ikkeGaulaUtenforFriksjon)*0.05)):
    midlertidigListe.append(ikkeGaulaUtenforFriksjon[i])
ikkeGaulaUtenforFriksjon5persentilListe = midlertidigListe
midlertidigListe = []
for i in range(round(len(ikkeGaulaBruFriksjon)*0.15)):
    midlertidigListe.append(ikkeGaulaBruFriksjon[i])
ikkeGaulaBruFriksjon15persentilListe = midlertidigListe
midlertidigListe = []
for i in range(round(len(ikkeGaulaUtenforFriksjon)*0.15)):
    midlertidigListe.append(ikkeGaulaUtenforFriksjon[i])
ikkeGaulaUtenforFriksjon15persentilListe = midlertidigListe

gaulaBruFriksjon5persentilArray = np.asarray(gaulaBruFriksjon5persentilListe)
gaulaUtenforFriksjon5persentilArray = np.asarray(gaulaUtenforFriksjon5persentilListe)
gaulaBruFriksjon15persentilArray = np.asarray(gaulaBruFriksjon15persentilListe)
gaulaUtenforFriksjon15persentilArray = np.asarray(gaulaUtenforFriksjon15persentilListe)
ikkeGaulaBruFriksjon5persentilArray = np.asarray(ikkeGaulaBruFriksjon5persentilListe)
ikkeGaulaUtenforFriksjon5persentilArray = np.asarray(ikkeGaulaUtenforFriksjon5persentilListe)
ikkeGaulaBruFriksjon15persentilArray = np.asarray(ikkeGaulaBruFriksjon15persentilListe)
ikkeGaulaUtenforFriksjon15persentilArray = np.asarray(ikkeGaulaUtenforFriksjon15persentilListe)

gaulaSignifikans = scipy.stats.ttest_ind(gaulaBruFriksjon, 
                                         gaulaUtenforFriksjon,
                                         equal_var=True, alternative='less')
gaula5persentilSignifikans = scipy.stats.ttest_ind(gaulaBruFriksjon5persentilArray, 
                                                   gaulaUtenforFriksjon5persentilArray,
                                                   equal_var=True, alternative='less')
gaula15persentilSignifikans = scipy.stats.ttest_ind(gaulaBruFriksjon15persentilArray, 
                                                    gaulaUtenforFriksjon15persentilArray,
                                                    equal_var=True, alternative='less')

ikkeGaulaSignifikans = scipy.stats.ttest_ind(ikkeGaulaBruFriksjon, ikkeGaulaUtenforFriksjon,
                                             equal_var=True, alternative='less')
ikkeGaula5persentilSignifikans = scipy.stats.ttest_ind(ikkeGaulaBruFriksjon5persentilArray,
                                                       ikkeGaulaUtenforFriksjon5persentilArray,
                                                       equal_var=True, alternative='less')
ikkeGaula15persentilSignifikans = scipy.stats.ttest_ind(ikkeGaulaBruFriksjon15persentilArray,
                                                        ikkeGaulaUtenforFriksjon15persentilArray,
                                                        equal_var=True, alternative='less')
gaulaBruIkkeGaulaBruSignifikans = scipy.stats.ttest_ind(gaulaBruFriksjon, ikkeGaulaBruFriksjon,
                                                        equal_var=True, alternative='less')

print(len(gaulaBruFriksjon))
print(len(gaulaUtenforFriksjon))
print(len(gaulaAlleFriksjon))
print(len(ikkeGaulaBruFriksjon))
print(len(ikkeGaulaUtenforFriksjon))
print(len(ikkeGaulaAlleFriksjon))

print('Gaula bru: 5-persentil: {}, 15-persentil: {}, Gjennomsnitt: {}'.format(gaulaBru5persentil, gaulaBru15persentil, gaulaBruGjennomsnitt))
print('Gaula utenfor: 5-persentil: {}, 15-persentil: {}, Gjennomsnitt: {}'.format(gaulaUtenfor5persentil, gaulaUtenfor15persentil, gaulaUtenforGjennomsnitt))
print('Gaula alle: 5-persentil: {}, 15-persentil: {}, Gjennomsnitt: {}'.format(gaulaAlle5persentil, gaulaAlle15persentil, gaulaAlleGjennomsnitt))
print('Ikke Gaula bru: 5-persentil: {}, 15-persentil: {}, Gjennomsnitt: {}'.format(ikkeGaulaBru5persentil, ikkeGaulaBru15persentil, ikkeGaulaBruGjennomsnitt))
print('Ikke Gaula utenfor: 5-persentil: {}, 15-persentil: {}, Gjennomsnitt: {}'.format(ikkeGaulaUtenfor5persentil, ikkeGaulaUtenfor15persentil, ikkeGaulaUtenforGjennomsnitt))
print('Ikke Gaula alle: 5-persentil: {}, 15-persentil: {}, Gjennomsnitt: {}'.format(ikkeGaulaAlle5persentil, ikkeGaulaAlle15persentil, ikkeGaulaAlleGjennomsnitt))
print('\n')
print('P-verdi for totalfriksjon, 5-persentil, på bru sammenlignet med utenfor bru for Gaulabrua: {}'.format(gaula5persentilSignifikans[1]))
print('P-verdi for totalfriksjon, 15-persentil, på bru sammenlignet med utenfor bru for Gaulabrua: {}'.format(gaula15persentilSignifikans[1]))
print('P-verdi for totalfriksjon, gjennomsnitt, på bru sammenlignet med utenfor bru for Gaulabrua: {}'.format(gaulaSignifikans[1]))
print('P-verdi for totalfriksjon, 5-persentil, på bru sammenlignet med utenfor bru for Ikke Gaulabrua: {}'.format(ikkeGaula5persentilSignifikans[1]))
print('P-verdi for totalfriksjon, 15-persentil, på bru sammenlignet med utenfor bru for Ikke Gaulabrua: {}'.format(ikkeGaula15persentilSignifikans[1]))
print('P-verdi for totalfriksjon, gjennomsnitt, på bru sammenlignet med utenfor bru for Ikke Gaulabrua: {}'.format(ikkeGaulaSignifikans[1]))
print('P-verdi for totalfriksjon, gjennomsnitt, på Gaulabrua sammenlignet med på bruer som ikke er Gaulabrua: {}'.format(gaulaBruIkkeGaulaBruSignifikans[1]))

fig = plt.figure(figsize=(9, 6))
fig.suptitle('Densitetsfordeling til målepunkter med vinterdriftsklasse B, høy', fontsize=20)
fig.subplots_adjust(left=0.08, bottom=0.19, right=0.94, top=0.9, wspace=0.32, hspace=0.35)
ax = fig.add_subplot(111)

x_verdier = np.linspace(0, 0.7)
densitet1 = gaussian_kde(gaulaAlleFriksjon)
densitet1.covariance_factor = lambda: .5
densitet1._compute_covariance()
densitet2 = gaussian_kde(ikkeGaulaAlleFriksjon)
densitet2.covariance_factor = lambda: .5
densitet2._compute_covariance()

ax.plot(x_verdier, densitet1(x_verdier), label='Gaulabrua')
ax.plot(x_verdier, densitet2(x_verdier), label='Ikke Gaulabrua')
ax.set_ylabel('Densitet', fontsize=15)
ax.set_xlabel('Totalfriksjonsverdi', fontsize=15)
tick_spacing = 0.05
ax.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax.set_xlim([0, 0.7])
ax.tick_params(right=True, left=True, bottom=True)
fig.legend(loc=8, ncol=2, fontsize=15)


fig = plt.figure(figsize=(12, 6))
fig.suptitle('Densitetsfordeling til målepunkter med vinterdriftsklasse B, høy', fontsize=20)
fig.subplots_adjust(left=0.08, bottom=0.23, right=0.94, top=0.9, wspace=0.32, hspace=0.35)
ax = fig.add_subplot(121)
ax2 = fig.add_subplot(122)

x_verdier = np.linspace(0, 0.7)
densitet3 = gaussian_kde(gaulaBruFriksjon)
densitet3.covariance_factor = lambda: .5
densitet3._compute_covariance()
densitet4 = gaussian_kde(gaulaUtenforFriksjon)
densitet4.covariance_factor = lambda: .5
densitet4._compute_covariance()
densitet5 = gaussian_kde(ikkeGaulaBruFriksjon)
densitet5.covariance_factor = lambda: .5
densitet5._compute_covariance()
densitet6 = gaussian_kde(ikkeGaulaUtenforFriksjon)
densitet6.covariance_factor = lambda: .5
densitet6._compute_covariance()

ax.plot(x_verdier, densitet3(x_verdier), label='Gaulabrua')
ax.plot(x_verdier, densitet4(x_verdier), label='Utenfor Gaulabrua', c='brown')
ax.set_ylabel('Densitet', fontsize=15)
ax.set_xlabel('Totalfriksjonsverdi', fontsize=15)
tick_spacing = 0.1
ax.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax.set_xlim([0, 0.7])
ax.set_ylim([0, 9])
ax.tick_params(right=True, left=True, bottom=True)

ax2.plot(x_verdier, densitet5(x_verdier), label='Ikke Gaulabrua', c='coral')
ax2.plot(x_verdier, densitet6(x_verdier), label='Utenfor ikke Gaulabrua', c='grey')
ax2.set_ylabel('Densitet', fontsize=15)
ax2.set_xlabel('Totalfriksjonsverdi', fontsize=15)
ti2ck_spacing = 0.1
ax2.xaxis.set_major_locator(ticker.MultipleLocator(tick_spacing))
ax2.set_xlim([0, 0.7])
ax2.set_ylim([0, 9])
ax2.tick_params(right=True, left=True, bottom=True)
fig.legend(loc=8, ncol=2, fontsize=15)

plt.show()
