import glob
import csv

# Oppgi sti hvor mappen Programmering ligger lagret
sti = 'C:\\Programmering\\'

# Samler stiene til filene som passerer grovsilingen i en vektor
relevanteFiler = []

# Variabler som teller hvor mange filer som passerer hver enkelt test i grovsilingen
filTeller = 0
tomFilTeller = 0
liteDataTeller = 0
hoyTemperaturTeller = 0
ikkeUlikePunkterTeller = 0
konstantFriksjonTeller = 0
ugyldigVegTeller = 0
vellykedeTeller = 0

# De første for-løkkene henter og starter behandling av filene
filSti = sti + 'Friksjonsmålinger\\Rådata\\*'
mappeListe = glob.glob(filSti)
for mappe in mappeListe:
    filListe = glob.glob(mappe + '\\*')
    filTeller = filTeller + len(filListe)
    for fil in filListe:

        testScore = [-1, -1, -1, -1, -1, -1]  # Lager en vektor som holder styr på hvilke tester filen passerer, 1 = godkjent test, -1 = ikke godkjent test
        friksjonVerdierListe = []   # Lager en vektor som holder friksjsjonsverdiene
        lengdegradListe = []  # Lager en vektor som holder lengdegrader
        breddegradListe = []  # Lager en vektor som holder breddegrader
        linjeTeller = -1  # Lager en teller for antall linjer i filene

        with open(fil, "r") as originalFil:

            # Teller antall linjer i fila og noterer relevant metadata underveis
            for linje in originalFil:
                linjeTeller = linjeTeller + 1
                if linjeTeller == 17:
                    veg = linje[5:].strip()
                if linjeTeller == 27:
                    if linje[18:] != '':
                        distanse = int(linje[18:])
                    else:
                        distanse = 0

            # Nulte test sjekker om filen har data og dermed om den kan testes for flere testkriterier
            if linjeTeller > 29:
                testScore[0] = 1

                # Første test sjekker om filen har mer enn tre linjer som dekker 300 meter
                if linjeTeller > 31 and distanse >= 300:
                    testScore[1] = 1

            originalFil.seek(0)  # Går til starten av filen igjen

            # Leser av andre nyttige verdier på CSV-format
            aktivFil_reader = csv.reader(originalFil, delimiter='\t')
            for i in range(30):  # Bruker for-løkken til å hoppe over de første 30 linjene med metadata
                next(aktivFil_reader)
            for linje in aktivFil_reader:
                friksjonVerdierListe.append(float(linje[3].replace(',', '.')))
                lengdegradListe.append(float(linje[8].replace(',', '.')))
                breddegradListe.append(float(linje[9].replace(',', '.')))

                # Andre test sjekker om det finnes målinger for overflatetemperatur eller lufttemperatur som er lavere enn 1.
                if linje[5] != '' and linje[6] != '':
                    if float(linje[5].replace(',', '.')) < 1 or float(linje[6].replace(',', '.')) < 1:  # Sjekker om det finnes målinger for overflatetemperatur eller lufttemperatur som er lavere enn 1.
                        testScore[2] = 1

            # Tredje test sjekker om lengdegrad og breddegrad endrer seg
            for i in range(len(lengdegradListe) - 1):  # Sjekker om lengdegrad og breddegrad endrer seg
                if lengdegradListe[i] != lengdegradListe[i + 1] or breddegradListe[i] != breddegradListe[i + 1]:
                    testScore[3] = 1

            # Fjerde test
            for i in range(len(friksjonVerdierListe) - 1):  # Sjekker om friksjonsverdien endrer seg
                if friksjonVerdierListe[i] != friksjonVerdierListe[i + 1]:
                    testScore[4] = 1

            # Femte test sjekker at filen har oppgit vegen som er målt på gyldig format
            if veg != '':  # Sjekker at vegen har et navn
                if len(veg) - len(veg.replace(' ', '')) == 0:  # Sjekker at vegen ikke har mellomrom i navnet
                    if veg[:2] == 'FV' or veg[:2] == 'EV' or veg[:2] == 'KV':  # Sjekker om vegen er en fylkesveg, europaveg eller kommunal veg
                        testScore[5] = 1
                    elif veg[:2] == 'RV' and veg != 'RV000':  # Sjekker om vegen er en gyldig riksveg
                        testScore[5] = 1

        # Teller hvilke tester filen har passert
        if testScore[0] == 1:
            if testScore[1] == -1:
                liteDataTeller = liteDataTeller + 1
            if testScore[2] == -1:
                hoyTemperaturTeller = hoyTemperaturTeller + 1
            if testScore[3] == -1:
                ikkeUlikePunkterTeller = ikkeUlikePunkterTeller + 1
            if testScore[4] == -1:
                konstantFriksjonTeller = konstantFriksjonTeller + 1
            if testScore[5] == -1:
                ugyldigVegTeller = ugyldigVegTeller + 1
        else:
            tomFilTeller = tomFilTeller + 1

        # Samler stier til filer som har bestått alle tester i en vektor
        if sum(testScore) == 6:
            vellykedeTeller = vellykedeTeller + 1
            relevanteFiler.append(fil)

# Samler stier til alle relevante filer i et tekstdokumentre
QGIS_input = sti + 'Friksjonsmålinger\\QGIS_input\\Input.txt'
with open(QGIS_input, 'w+') as output:
    for filer in relevanteFiler:
        splittetSti = filer.split('\\')
        output.write(splittetSti[-4] + '\\' + splittetSti[-3] + '\\' + splittetSti[-2] + '\\' + splittetSti[-1] + '\n')

# Printer ut informasjon om antall filer som har passert testene
print('Antall filer: {} stykker'.format(filTeller))
print('Antall tomme filer: {} stykker'.format(tomFilTeller))
print('Antall filer med data: {} stykker = 100%'.format(filTeller-tomFilTeller))
print('Antall filer med for lite data: {} stykker = {:.2f}%'.format(liteDataTeller, liteDataTeller/(filTeller-tomFilTeller)*100))
print('Antall filer med for høy temperatur: {} stykker = {:.2f}%'.format(hoyTemperaturTeller, hoyTemperaturTeller/(filTeller-tomFilTeller)*100))
print('Antall filer som kun måler ett punkt: {} stykker = {:.2f}%'.format(ikkeUlikePunkterTeller, ikkeUlikePunkterTeller/(filTeller-tomFilTeller)*100))
print('Antall filer med konstant friksjon: {} stykker = {:.2f}%'.format(konstantFriksjonTeller, konstantFriksjonTeller/(filTeller-tomFilTeller)*100))
print('Antall filer med ugyldige veger: {} stykker = {:.2f}%'.format(ugyldigVegTeller, ugyldigVegTeller/(filTeller-tomFilTeller)*100))
print('Antall vellykkede filer: {} stykker = {:.2f}%'.format(vellykedeTeller, vellykedeTeller/(filTeller-tomFilTeller)*100))
