def FinnFiler(sti):
    import codecs
    
    filListe = []
    inputFiler = sti + 'Friksjonsmålinger\\QGIS_input\\Input.txt'

    # Henter filstiene til filene som skal behand
    with codecs.open(inputFiler, 'r', 'latin-1') as QGIS_input:  # Åpner filen med dekodingingen latin1 for å kunne lese filnavn med æ, ø og å
        for fil in QGIS_input:
            filListe.append(sti + fil.rstrip())
    return(filListe)


def FilInformasjon(fil):
    # Definerer en vektor som holder data underveis
    originaleLinjer = []

    # Leser metadata fra filen og legger det til vektoren
    f = open(fil, "r", encoding="latin-1")
    for position, line in enumerate(f):
        originaleLinjer.append(line)
        if position == 28:
            break
    f.close()

    # Noterer informasjon filnavn og veg
    filnavn = originaleLinjer[3][9:].strip()
    veg = originaleLinjer[17][5:].strip()

    return(originaleLinjer, filnavn, veg)


def LeggTilMaalinger(fil):
    import processing
    from qgis.core import QgsVectorLayer, QgsVectorFileWriter, QgsCoordinateReferenceSystem, QgsProject

    # Definerer hvordan filen skal leses og behandles
    uri = 'file:///{}?encoding=latin1&type=csv&delimiter=%5Ct&skipLines=28&maxFields=10000&detectTypes=yes&decimalPoint=,&xField=Long%20[%C2%B0]&yField=Lat%20[%C2%B0]&crs=EPSG:4326&spatialIndex=no&subsetIndex=no&watchFile=no'.format(fil.replace('å', '%C3%A5'))

    # Ber QGIS om å ta inn filen som et vektorlag
    friksjonspunkter = QgsVectorLayer(uri, "FriksjonPunkter", "delimitedtext")
    QgsProject.instance().addMapLayer(friksjonspunkter)

    # Lager en utstrekning som dekker friksjonspunktene
    processing.runAndLoadResults("native:polygonfromlayerextent", {'INPUT': friksjonspunkter,
                  'ROUND_TO': 0,
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    utstrekning = QgsProject.instance().mapLayersByName('Extent')[0]

    # Omprojiserer utstrekningen fra WGS84 til UTM33
    processing.runAndLoadResults("native:reprojectlayer", {'INPUT': utstrekning,
                  'TARGET_CRS': QgsCoordinateReferenceSystem('EPSG:5973'),
                  'OPERATION': '+proj=pipeline +step +proj=unitconvert +xy_in=deg +xy_out=rad +step +proj=utm +zone=33 +ellps=GRS80',
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    omprojisertUtstrekning = QgsProject.instance().mapLayersByName('Reprojected')[0]

    # Endrer koordinatsystemet i QGIS til UTM33
    QgsProject.instance().setCrs(QgsCoordinateReferenceSystem(5973))

    # Definerer koordinatene som dekker utstrekningen
    ext = omprojisertUtstrekning.extent()
    kartutsnitt = str(ext.xMinimum()) + ',' + \
                str(ext.yMinimum()) + ',' + str(ext.xMaximum()) + \
                ',' + str(ext.yMaximum()) 
    return(kartutsnitt)


def LeggTilBru(veg, kartutsnitt):
    from nvdbapiv3 import nvdbFagdata
    from nvdbapiV3qgis3 import nvdbsok2qgis

    # Henter bruer fra NVDB
    sokeobj = nvdbFagdata(60) 
    sokeobj.filter({'vegsystemreferanse': veg})  # Aktuell veg
    sokeobj.filter({'egenskap': '11317=19262 AND 1263=7304'})  # Kun trafikkerte vegbruer
    sokeobj.filter({'srid' : 'utm33'})  # Setter CRS for kartutsnittet
    sokeobj.filter({'kartutsnitt': kartutsnitt })  # Begrenser området det hentes data fra
    nvdbsok2qgis(sokeobj)


def TestBruEksistens():
    from qgis.core import QgsProject
    
    # Returnerer 1 dersom bruer har blitt importert, ellers returneres -1
    resultat = -1
    lagListe = QgsProject.instance().mapLayers()
    for lag in lagListe:
        if lag[:3] == 'Bru' and lag[:6] != 'Bru_2d':
            resultat = 1
    return(resultat)


def LeggTilDriftsklasse(veg, kartutsnitt):
    from nvdbapiv3 import nvdbFagdata
    from nvdbapiV3qgis3 import nvdbsok2qgis

    # Henter vinterdriftsklasser fra NVDB
    sokeobj = nvdbFagdata(810) 
    sokeobj.filter({'vegsystemreferanse': veg})  # Aktuell veg
    sokeobj.filter({'egenskap': '9260!=12909 OR 9260!=12910 OR 9260!=15876'})  # Ikke GsA, GsB eller sideanlegg
    sokeobj.filter({'srid': 'utm33'})  # Setter CRS for kartutsnittet
    sokeobj.filter({'kartutsnitt': kartutsnitt})  # Begrenser området det hentes data fra
    nvdbsok2qgis(sokeobj)


def LeggTilKurvatur(veg, kartutsnitt):
    from nvdbapiv3 import nvdbFagdata
    from nvdbapiV3qgis3 import nvdbsok2qgis

    # Henter horisontalelementer fra NVDB
    sokeobj = nvdbFagdata(639) 
    sokeobj.filter({'vegsystemreferanse': veg})  # Aktuell veg
    sokeobj.filter({'srid': 'utm33' })  # Setter CRS for kartutsnittet
    sokeobj.filter({'kartutsnitt': kartutsnitt})  # Begrenser området det hentes data fra
    nvdbsok2qgis(sokeobj)


def LagBuffer():
    import processing
    from qgis.core import QgsVectorLayer, QgsProject, QgsField, edit, QgsCoordinateReferenceSystem
    from PyQt5.QtCore import QVariant

    # Sjekker om det finnes lag for kurvatur og vinterdriftsklasse
    kurvatur = -1
    driftsklasse = -1
    lagListe = QgsProject.instance().mapLayers()
    for lag in lagListe:
        if lag[:8] == 'Kurvatur':
            kurvatur = 1
        if lag[:18] == 'Vinterdriftsklasse':
            driftsklasse = 1

    if kurvatur == -1:
        # Opretter et tomt lag for kurvatur som kan brukes videre i behandlingen
        tomKurvatur = QgsVectorLayer("Point", "TomKurvatur", "memory")
        with edit(tomKurvatur):
            tomKurvatur.addAttribute(QgsField('Radius', QVariant.String))
            tomKurvatur.updateFields()
        processing.runAndLoadResults("native:reprojectlayer", {'INPUT':tomKurvatur,
                  'TARGET_CRS':QgsCoordinateReferenceSystem('EPSG:5973'),
                  'OPERATION':'+proj=pipeline +step +proj=unitconvert +xy_in=deg +xy_out=rad +step +proj=utm +zone=33 +ellps=GRS80',
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
        omprojisertTomKurvatur = QgsProject.instance().mapLayersByName('Reprojected')[0]
        processing.runAndLoadResults("qgis:renamelayer", {'INPUT': omprojisertTomKurvatur,
                  'NAME': 'Kurvatur, horisontalelement'})

    if driftsklasse == -1:
        # Opretter et tomt lag for vinterdriftsklasse som kan brukes videre i behandlingen
        tomVinterdriftsklasse = QgsVectorLayer("Point", "TomVinterdriftsklasse", "memory")
        with edit(tomVinterdriftsklasse):
            tomVinterdriftsklasse.addAttribute(QgsField('Driftsklasse', QVariant.String))
            tomVinterdriftsklasse.updateFields()
        processing.runAndLoadResults("native:reprojectlayer", {'INPUT':tomVinterdriftsklasse,
                  'TARGET_CRS':QgsCoordinateReferenceSystem('EPSG:5973'),
                  'OPERATION':'+proj=pipeline +step +proj=unitconvert +xy_in=deg +xy_out=rad +step +proj=utm +zone=33 +ellps=GRS80',
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
        omprojisertTomVinterdriftsklasse = QgsProject.instance().mapLayersByName('Reprojected')[0]
        processing.runAndLoadResults("qgis:renamelayer", {'INPUT': omprojisertTomVinterdriftsklasse,
                  'NAME': 'Vinterdriftsklasse'})

    # Lager en buffer som gir bruene en total bredde på 20 meter og som stopper der brua stopper i lengderetning
    bruer = QgsProject.instance().mapLayersByName('Bru')[0]
    processing.runAndLoadResults("native:buffer", {'INPUT': bruer,
                  'DISTANCE': 10,
                  'SEGMENTS': 5,
                  'END_CAP_STYLE': 1,
                  'JOIN_STYLE': 1,
                  'MITER_LIMIT': 2,
                  'DISSOLVE': False,
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    bruBuffer = QgsProject.instance().mapLayersByName('Buffered')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': bruBuffer,
                  'NAME': 'BruBuffer'})

    # Lager buffer rundt driftsklassene
    vinterdriftsklasse = QgsProject.instance().mapLayersByName('Vinterdriftsklasse')[0]
    processing.runAndLoadResults("native:buffer", {'INPUT': vinterdriftsklasse,
                  'DISTANCE': 10,
                  'SEGMENTS': 5,
                  'END_CAP_STYLE': 1,
                  'JOIN_STYLE': 1,
                  'MITER_LIMIT': 2,
                  'DISSOLVE': False,
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    vinterdriftsklasseBuffer = QgsProject.instance().mapLayersByName('Buffered')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': vinterdriftsklasseBuffer,
                  'NAME': 'VinterdriftsklasseBuffer'})

    # Lager buffer rundt kurvaturen
    kurvatur = QgsProject.instance().mapLayersByName('Kurvatur, horisontalelement')[0]
    processing.runAndLoadResults("native:buffer", {'INPUT': kurvatur,
                  'DISTANCE': 10,
                  'SEGMENTS': 5,
                  'END_CAP_STYLE': 1,
                  'JOIN_STYLE': 1,
                  'MITER_LIMIT': 2,
                  'DISSOLVE': False,
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    kurvaturBuffer = QgsProject.instance().mapLayersByName('Buffered')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': kurvaturBuffer,
                  'NAME': 'KurvaturBuffer'})


def ArvNVDB_Bru():
    import processing
    from qgis.core import QgsProject, QgsField, QgsFeature, NULL, edit
    from PyQt5.QtCore import QVariant

    # Finner endepunktene til bruene
    bruer = QgsProject.instance().mapLayersByName('Bru')[0]
    processing.runAndLoadResults("native:extractspecificvertices", {'INPUT':bruer,
                  'VERTICES':'0, -1',
                  'OUTPUT':'TEMPORARY_OUTPUT'})
    bruEndepunkter = QgsProject.instance().mapLayersByName('Vertices')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': bruEndepunkter,
                  'NAME': 'BruEndepunkter'})

    # Lager et buffer rundt endepunktene
    bruEndepunkter = QgsProject.instance().mapLayersByName('BruEndepunkter')[0]
    processing.runAndLoadResults("native:buffer", {'INPUT':bruEndepunkter,
                  'DISTANCE':100,
                  'SEGMENTS':5,
                  'END_CAP_STYLE':0,
                  'JOIN_STYLE':0,
                  'MITER_LIMIT':2,
                  'DISSOLVE':False,
                  'OUTPUT':'TEMPORARY_OUTPUT'})
    bruEndepunkterBuffer = QgsProject.instance().mapLayersByName('Buffered')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': bruEndepunkterBuffer,
                  'NAME': 'BruEndepunkterBuffer'})

    # Lager to korrigerte buffer
    # Første buffer kombinerer brubufferet med bufferet rundt endepunktene
    # Andre buffer ekskluderer brubufferet fra bufferet til endepunktene
    bruEndepunkterBuffer = QgsProject.instance().mapLayersByName('BruEndepunkterBuffer')[0]
    bruBuffer = QgsProject.instance().mapLayersByName('BruBuffer')[0]
    processing.runAndLoadResults("native:union", {'INPUT':bruEndepunkterBuffer,
                  'OVERLAY':bruBuffer,
                  'OVERLAY_FIELDS_PREFIX':'',
                  'OUTPUT':'TEMPORARY_OUTPUT'})
    altBruBuffer = QgsProject.instance().mapLayersByName('Union')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': altBruBuffer,
                  'NAME': 'AltBruBuffer'})
    processing.runAndLoadResults("native:difference", {'INPUT': bruEndepunkterBuffer,
                  'OVERLAY': bruBuffer,
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    inngangBruBuffer = QgsProject.instance().mapLayersByName('Difference')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': inngangBruBuffer,
                  'NAME': 'InngangBruBuffer'})

    # Finner alle målepunkter på og ved inngangen til bruene
    friksjonPunkter = QgsProject.instance().mapLayersByName('FriksjonPunkter')[0]
    altBruBuffer = QgsProject.instance().mapLayersByName('AltBruBuffer')[0]
    processing.runAndLoadResults("native:intersection", {'INPUT': friksjonPunkter,
                  'OVERLAY': altBruBuffer,
                  'INPUT_FIELDS': '',
                  'OVERLAY_FIELDS': ['nvdbid','Byggverkstype','Materialtype','Lengde','Byggeår'],
                  'OVERLAY_FIELDS_PREFIX': '',
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    alleBruPunkter = QgsProject.instance().mapLayersByName('Intersection')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': alleBruPunkter,
                  'NAME': 'AlleBruPunkter'})

    # Finner målepunkter som er ved inngangen til brua = Friksjonspunkter som er mindre enn 100 meter unna en bru, men ikke på en bru
    alleBruPunkter = QgsProject.instance().mapLayersByName('AlleBruPunkter')[0]
    inngangBruBuffer = QgsProject.instance().mapLayersByName('InngangBruBuffer')[0]
    processing.runAndLoadResults("native:intersection", {'INPUT': alleBruPunkter,
                  'OVERLAY': inngangBruBuffer,
                  'INPUT_FIELDS': '',
                  'OVERLAY_FIELDS': '',
                  'OVERLAY_FIELDS_PREFIX': '',
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    inngangBruPunkter = QgsProject.instance().mapLayersByName('Intersection')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': inngangBruPunkter,
                  'NAME': 'InngangBruPunkter'})

    # Finner distanser fra punktene til bruenes endepunkter
    inngangBruPunkter = QgsProject.instance().mapLayersByName('InngangBruPunkter')[0]
    bruEndepunkter = QgsProject.instance().mapLayersByName('BruEndepunkter')[0]  # Gjentar linjen fra tidligere for å forbedre lesbarhet
    processing.runAndLoadResults("qgis:distancetonearesthublinetohub", {'INPUT': inngangBruPunkter,
                  'HUBS': bruEndepunkter,
                  'FIELD': 'nvdbid',
                  'UNIT': 0,
                  'OUTPUT': 'TEMPORARY_OUTPUT'})
    avstandTilBru = QgsProject.instance().mapLayersByName('Hub distance')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': avstandTilBru,
                  'NAME': 'AvstandTilBru'})

    # Legger til distansene til laget med alle inngangspunktene
    alleBruPunkter = QgsProject.instance().mapLayersByName('AlleBruPunkter')[0]
    avstandTilBru = QgsProject.instance().mapLayersByName('AvstandTilBru')[0]
    processing.runAndLoadResults("native:joinattributesbylocation", {'INPUT': alleBruPunkter,
                  'JOIN':avstandTilBru,
                  'PREDICATE':[0],
                  'JOIN_FIELDS':['HubDist'],
                  'METHOD':0,
                  'DISCARD_NONMATCHING':False,
                  'PREFIX':'',
                  'OUTPUT':'TEMPORARY_OUTPUT'})
    alleBruPunkterMedLengder = QgsProject.instance().mapLayersByName('Joined layer')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': alleBruPunkterMedLengder,
                  'NAME': 'AlleBruPunkterMedLengder'})

    # Oppdaterer verdiene på bruer fra NULL til 0
    alleBruPunkterMedLengder = QgsProject.instance().mapLayersByName('AlleBruPunkterMedLengder')[0]
    egenskapNavn11 = 'Lengde'
    egenskapNavn12 = 'Brulengde [m]'
    egenskapNavn21 = 'HubDist'
    egenskapNavn22 = 'Avstand til bru [m]'
    egenskapVerdi1 = NULL
    egenskapVerdi2 = '0'
    with edit(alleBruPunkterMedLengder):
        for felt in alleBruPunkterMedLengder.fields():
            if felt.name() == egenskapNavn11:
                idx = alleBruPunkterMedLengder.fields().indexFromName(felt.name())
                alleBruPunkterMedLengder.renameAttribute(idx, egenskapNavn12)
            if felt.name() == egenskapNavn21:
                idx = alleBruPunkterMedLengder.fields().indexFromName(felt.name())
                alleBruPunkterMedLengder.renameAttribute(idx, egenskapNavn22)
            alleBruPunkterMedLengder.updateFields()
        for egenskap in alleBruPunkterMedLengder.getFeatures():
            if egenskap[egenskapNavn22] == egenskapVerdi1:
                egenskap[egenskapNavn22] = egenskapVerdi2
            alleBruPunkterMedLengder.updateFeature(egenskap)


def ArvNVDB_Annet():
    import processing
    from qgis.core import QgsProject

    alleBruPunkterMedLengder = QgsProject.instance().mapLayersByName('AlleBruPunkterMedLengder')[0]
    vinterdriftsklasseBuffer = QgsProject.instance().mapLayersByName('VinterdriftsklasseBuffer')[0]
    processing.runAndLoadResults("native:joinattributesbylocation", {'INPUT': alleBruPunkterMedLengder,
                  'JOIN':vinterdriftsklasseBuffer,
                  'PREDICATE':[0],
                  'JOIN_FIELDS':['Driftsklasse'],
                  'METHOD':0,
                  'DISCARD_NONMATCHING':False,
                  'PREFIX':'',
                  'OUTPUT':'TEMPORARY_OUTPUT'})
    friksjonPunkter_Bru_DK = QgsProject.instance().mapLayersByName('Joined layer')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': friksjonPunkter_Bru_DK,
                  'NAME': 'FriksjonPunkter_Bru_DK'})

    friksjonPunkter_Bru_DK = QgsProject.instance().mapLayersByName('FriksjonPunkter_Bru_DK')[0]
    kurvaturBuffer = QgsProject.instance().mapLayersByName('KurvaturBuffer')[0]
    processing.runAndLoadResults("native:joinattributesbylocation", {'INPUT': friksjonPunkter_Bru_DK,
                  'JOIN':kurvaturBuffer,
                  'PREDICATE':[0],
                  'JOIN_FIELDS':['Radius'],
                  'METHOD':0,
                  'DISCARD_NONMATCHING':False,
                  'PREFIX':'',
                  'OUTPUT':'TEMPORARY_OUTPUT'})
    friksjonPunkter_Bru_DK_R = QgsProject.instance().mapLayersByName('Joined layer')[0]
    processing.runAndLoadResults("qgis:renamelayer", {'INPUT': friksjonPunkter_Bru_DK_R,
                  'NAME': 'FriksjonPunkter_Bru_DK_R'})


def FerdigFil(sti, filnavn, metaDataLinjer):
    from qgis.core import QgsProject
    utSti = sti + 'Friksjonsmålinger\\QGIS_output\\' + filnavn

    friksjonPunkter_Bru_DK_R = QgsProject.instance().mapLayersByName('FriksjonPunkter_Bru_DK_R')[0]
    
    feltListe = []
    for felt in friksjonPunkter_Bru_DK_R.fields():
        feltListe.append(felt.name())
    
    with open(utSti, 'w') as utFil:
        for linje in metaDataLinjer:
            utFil.write(linje)
        for i in range(len(feltListe) - 1):
            utFil.write('{}\t'.format(feltListe[i]))
        utFil.write('{}\n'.format(feltListe[len(feltListe)-1]))
        for felt in friksjonPunkter_Bru_DK_R.getFeatures():
            for i in range(len(feltListe) - 1):
                utFil.write('{}\t'.format(felt[feltListe[i]]))
            utFil.write('{}\n'.format(felt[feltListe[len(feltListe)-1]]))


def Nullstill():
    from qgis.core import QgsProject

    # Tilbakestiller midlertidige lag slik at de kan lukkes uten melding i brukergrensesnittet
    for lag in QgsProject.instance().mapLayers().values():
        lag.startEditing()
        lag.rollBack()
    QgsProject.instance().removeAllMapLayers()
